﻿--[[
	Library contains a few functions to help better utiltise the archaeology data
--]]
local MAJOR, MINOR = "LibArchaeology-0.1", tonumber("1") or 999
assert(LibStub, MAJOR.." requires LibStub")

local lib = LibStub:NewLibrary(MAJOR, MINOR)
if not lib then return end
lib.callbacks = lib.callbacks or LibStub("CallbackHandler-1.0"):New(lib)
local astrolabe = DongleStub("Astrolabe-1.0")
local priv = {}

local L = LibArchLocals

local watchFrame = CreateFrame("Frame")
watchFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
watchFrame:RegisterEvent("WORLD_MAP_UPDATE")
watchFrame:RegisterEvent("ZONE_CHANGED")
watchFrame:RegisterEvent("ZONE_CHANGED_NEW_AREA")
watchFrame:RegisterEvent("ZONE_CHANGED_INDOORS")
watchFrame:RegisterEvent("ARTIFACT_DIG_SITE_UPDATED")
watchFrame:RegisterEvent("CHAT_MSG_LOOT")
watchFrame:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED")
watchFrame:RegisterEvent("ARTIFACT_COMPLETE")
watchFrame:RegisterEvent("ARTIFACT_HISTORY_READY")
watchFrame:SetScript("OnEvent", function(frame, event, ...)
	if event == "WORLD_MAP_UPDATE" then
		priv:LoadTables()
	elseif event == "ARTIFACT_DIG_SITE_UPDATED" then
		lib:DigSiteUpdated()
	elseif event == "PLAYER_ENTERING_WORLD" then
		priv:LoadTables()
		lib:DigSiteUpdated()
	elseif event == "PLAYER_ENTERING_WORLD" or event == "ZONE_CHANGED_NEW_AREA"  then -- event == "ZONE_CHANGED" or event == "ZONE_CHANGED_INDOORS" then
		priv:MapChanged(false)
	elseif event == "CHAT_MSG_LOOT" then
		priv:CheckLoot(...)
	elseif event == "UNIT_SPELLCAST_SUCCEEDED" then
		priv:SpellCastSuccess(...)
	elseif event == "ARTIFACT_COMPLETE" then
		local name = ...
		local race, artifact = lib:GetArtifactInfoByArtifactName(name)
		lib.callbacks:Fire("ArtifactCompleted", race, artifact)
	elseif event == "ARTIFACT_HISTORY_READY" then
--		print("Artifact History Ready fired")
		lib.callbacks:Fire("ArtifactHistoryReady")
	end
end)


lib.SITE_TEXTURE_INDEX = 177
local floor = floor
local siteData = {}
local currSites = {}
local raceInfo = {}
local mapcz = {}
local currencies, races, keystones
local lastMap, lastFloor, lastBlobData
local lastSurveyPosition
local lastSite
local siteTranslation = {}
local surveyNodeIDs = { 
		[L["Night Elf Archaeology Find"]]      = 601,
		[L["Troll Archaeology Find"]]          = 602,
		[L["Dwarf Archaeology Find"]]          = 603,
		[L["Fossil Archaeology Find"]]         = 604,
		[L["Draenei Archaeology Find"]]        = 605,
		[L["Orc Archaeology Find"]]            = 606,
		[L["Nerubian Archaeology Find"]]       = 607,
		[L["Vrykul Archaeology Find"]]         = 608,
		[L["Tol'vir Archaeology Find"]]        = 609,
		[L["Other Archaeology Find"]]          = 610,
}

function priv:LoadTables(force)
	if not currencies or not races or not keystones or force then
		if GetNumArchaeologyRaces() == 0 then return end
		RequestArtifactCompletionHistory()
		currencies = currencies or {}
		races = races or {}
		keystones = keystones or {}
		for i = 1, GetNumArchaeologyRaces() do
			local name, currency, texture, stoneID = GetArchaeologyRaceInfo(i)
			races[name] = i
			local localCurrency = GetCurrencyInfo(currency)
			currencies[localCurrency] = name
			keystones[stoneID] = i
		end
		if currencies == {} then currencies = nil end
		if races == {} then races = nil end
		if keystones == {} then keystones = nil end
		lib.callbacks:Fire("ArchaeologyDataLoaded")
		if lib and lib.DigSiteUpdated then
			lib:DigSiteUpdated()
		end
	end
end


do
	siteData = {
		["Ironband's Excavation Site"] = { locales = { ["enUS"] = "Ironband's Excavation Site", ["enGB"] = "Ironband's Excavation Site", ["deDE"] = "Eisenbands Ausgrabungsstätte", ["esES"] = "Excavación de Vetaferro", ["esMX"] = "Excavación de Vetaferro", ["frFR"] = "Excavations de Baguefer", ["ruRU"] = "Раскопки Сталекрута", ["koKR"] = "아이언밴드의 발굴현장", ["zhTW"] = "鐵環挖掘場",  }, continent = 2, map = 35, blob = 54097, race = 1, points = {} }, 
		["Ironbeard's Tomb"] = { locales = { ["enUS"] = "Ironbeard's Tomb", ["enGB"] = "Ironbeard's Tomb", ["deDE"] = "Eisenbarts Grabmal", ["esES"] = "Tumba de Barbaférrea", ["esMX"] = "Tumba de Barbaférrea", ["frFR"] = "Tombe de Barbe-de-fer", ["ruRU"] = "Гробница Железноборода", ["koKR"] = "아이언비어드의 고분", ["zhTW"] = "鐵鬚之墓",  }, continent = 2, map = 40, blob = 54124, race = 1, points = {} }, 
		["Whelgar's Excavation Site"] = { locales = { ["enUS"] = "Whelgar's Excavation Site", ["enGB"] = "Whelgar's Excavation Site", ["deDE"] = "Whelgars Ausgrabungsstätte", ["esES"] = "Excavación de Whelgar", ["esMX"] = "Excavación de Whelgar", ["frFR"] = "Excavations de Whelgar", ["ruRU"] = "Раскопки Вельгара", ["koKR"] = "웰가르의 발굴현장", ["zhTW"] = "維爾加挖掘場",  }, continent = 2, map = 40, blob = 54126, race = 1, points = {} }, 
		["Greenwarden's Fossil Bank"] = { locales = { ["enUS"] = "Greenwarden's Fossil Bank", ["enGB"] = "Greenwarden's Fossil Bank", ["deDE"] = "Fossilienbank des Grünen Gürtels", ["esES"] = "Banco de fósiles del Guardaverde", ["esMX"] = "Banco de fósiles del Guardaverde", ["frFR"] = "Banc de fossiles du Gardien vert", ["ruRU"] = "Роща Стража Природы - ископаемая земля", ["koKR"] = "신록수호자의 화석 강둑", ["zhTW"] = "綠意守望者之林古河岸",  }, continent = 2, map = 40, blob = 54127, race = 3, points = {} }, 
		["Thoradin's Wall"] = { locales = { ["enUS"] = "Thoradin's Wall", ["enGB"] = "Thoradin's Wall", ["deDE"] = "Thoradinswall", ["esES"] = "Muralla de Thoradin", ["esMX"] = "Muralla de Thoradin", ["frFR"] = "Mur de Thoradin", ["ruRU"] = "Стена Торадина", ["koKR"] = "소라딘의 성벽", ["zhTW"] = "索拉丁之牆",  }, continent = 2, map = 16, blob = 54129, race = 1, points = {} }, 
		["Witherbark Digsite"] = { locales = { ["enUS"] = "Witherbark Digsite", ["enGB"] = "Witherbark Digsite", ["deDE"] = "Ausgrabungsstätte der Bleichborken", ["esES"] = "Excavación Secacorteza", ["esMX"] = "Excavación Secacorteza", ["frFR"] = "Site de fouilles de Fanécorce", ["ruRU"] = "Деревня Сухокожих - раскопки", ["koKR"] = "마른나무껍질 발굴현장", ["zhTW"] = "枯木挖掘場",  }, continent = 2, map = 16, blob = 54132, race = 8, points = {} }, 
		["Thandol Span"] = { locales = { ["enUS"] = "Thandol Span", ["enGB"] = "Thandol Span", ["deDE"] = "Thandolübergang", ["esES"] = "Puente Thandol", ["esMX"] = "Puente Thandol", ["frFR"] = "Viaduc de Thandol", ["ruRU"] = "Мост Тандола", ["koKR"] = "탄돌 교각", ["zhTW"] = "薩多爾大橋",  }, continent = 2, map = 40, blob = 54133, race = 1, points = {} }, 
		["Dun Garok Digsite"] = { locales = { ["enUS"] = "Dun Garok Digsite", ["enGB"] = "Dun Garok Digsite", ["deDE"] = "Ausgrabungsstätte von Dun Garok", ["esES"] = "Excavación de Dun Garok", ["esMX"] = "Excavación de Dun Garok", ["frFR"] = "Site de fouilles de Dun Garok", ["ruRU"] = "Дун Гарок - раскопки", ["koKR"] = "던 가록 발굴현장", ["zhTW"] = "丹加洛克挖掘場",  }, continent = 2, map = 24, blob = 54134, race = 1, points = {} }, 
		["Southshore Fossil Field"] = { locales = { ["enUS"] = "Southshore Fossil Field", ["enGB"] = "Southshore Fossil Field", ["deDE"] = "Fossilienfeld von Süderstade", ["esES"] = "Campo de fósiles de Costasur", ["esMX"] = "Campo de fósiles de Costasur", ["frFR"] = "Champ de fossiles d'Austrivage", ["ruRU"] = "Южнобережье - ископаемая почва", ["koKR"] = "남녘해안 화석 벌판", ["zhTW"] = "南海鎮古原野",  }, continent = 2, map = 24, blob = 54135, race = 3, points = {} }, 
		["Aerie Peak Digsite"] = { locales = { ["enUS"] = "Aerie Peak Digsite", ["enGB"] = "Aerie Peak Digsite", ["deDE"] = "Ausgrabungsstätte des Nistgipfels", ["esES"] = "Excavación de Pico Nidal", ["esMX"] = "Excavación de Pico Nidal", ["frFR"] = "Site de fouilles de Nid-de-l'Aigle", ["ruRU"] = "Заоблачный пик - раскопки", ["koKR"] = "맹금의 봉우리 발굴현장", ["zhTW"] = "鷹巢山挖掘場",  }, continent = 2, map = 26, blob = 54136, race = 1, points = {} }, 
		["Shadra'Alor Digsite"] = { locales = { ["enUS"] = "Shadra'Alor Digsite", ["enGB"] = "Shadra'Alor Digsite", ["deDE"] = "Ausgrabungsstätte von Shadra'Alor", ["esES"] = "Excavación de Shadra'Alor", ["esMX"] = "Excavación de Shadra'Alor", ["frFR"] = "Site de fouilles de Shadra'Alor", ["ruRU"] = "Шадра'Алор - раскопки", ["koKR"] = "샤드라알로 발굴현장", ["zhTW"] = "沙德拉洛挖掘場",  }, continent = 2, map = 26, blob = 54137, race = 8, points = {} }, 
		["Altar of Zul Digsite"] = { locales = { ["enUS"] = "Altar of Zul Digsite", ["enGB"] = "Altar of Zul Digsite", ["deDE"] = "Ausgrabungsstätte am Altars von Zul", ["esES"] = "Excavación de El Altar de Zul", ["esMX"] = "Excavación de El Altar de Zul", ["frFR"] = "Site de fouilles de l'autel de Zul", ["ruRU"] = "Алтарь Зула - раскопки", ["koKR"] = "줄의 제단 발굴현장", ["zhTW"] = "祖爾祭壇挖掘場",  }, continent = 2, map = 26, blob = 54138, race = 8, points = {} }, 
		["Jintha'Alor Lower City Digsite"] = { locales = { ["enUS"] = "Jintha'Alor Lower City Digsite", ["enGB"] = "Jintha'Alor Lower City Digsite", ["deDE"] = "Ausgrabungsstätte des unteren Viertels von Jintha'Alor", ["esES"] = "Excavación de la parte baja de Jintha'Alor", ["esMX"] = "Excavación de la parte baja de Jintha'Alor", ["frFR"] = "Site de fouilles de la ville basse de Jinth'Alor", ["ruRU"] = "Джинта'Алор, Нижний Город - раскопки", ["koKR"] = "진타알로 하층부 발굴현장", ["zhTW"] = "辛薩羅城下層挖掘場",  }, continent = 2, map = 26, blob = 54139, race = 8, points = {} }, 
		["Jintha'Alor Upper City Digsite"] = { locales = { ["enUS"] = "Jintha'Alor Upper City Digsite", ["enGB"] = "Jintha'Alor Upper City Digsite", ["deDE"] = "Ausgrabungsstätte des oberen Viertels von Jintha'Alor", ["esES"] = "Excavación de la parte alta de Jintha'Alor", ["esMX"] = "Excavación de la parte alta de Jintha'Alor", ["frFR"] = "Site de fouilles de la ville haute de Jinth'Alor", ["ruRU"] = "Джинта'Алор, Верхний Город - раскопки", ["koKR"] = "진타알로 상층부 발굴현장", ["zhTW"] = "辛薩羅城上層挖掘場",  }, continent = 2, map = 26, blob = 54140, race = 8, points = {} }, 
		["Agol'watha Digsite"] = { locales = { ["enUS"] = "Agol'watha Digsite", ["enGB"] = "Agol'watha Digsite", ["deDE"] = "Ausgrabungsstätte von Agol'watha", ["esES"] = "Excavación de Agol'watha", ["esMX"] = "Excavación de Agol'watha", ["frFR"] = "Site de fouilles d'Agol'watha", ["ruRU"] = "Агол'вата - раскопки", ["koKR"] = "아골와타 발굴현장", ["zhTW"] = "亞戈瓦薩挖掘場",  }, continent = 2, map = 26, blob = 54141, race = 8, points = {} }, 
		["Hammertoe's Digsite"] = { locales = { ["enUS"] = "Hammertoe's Digsite", ["enGB"] = "Hammertoe's Digsite", ["deDE"] = "Hammerzehs Grabungsstätte", ["esES"] = "Excavación de Piemartillo", ["esMX"] = "Excavación de Piemartillo", ["frFR"] = "Site de fouilles de Martèlorteil", ["ruRU"] = "Тяжелоступа - раскопки", ["koKR"] = "해머토의 발굴현장", ["zhTW"] = "鐵趾挖掘場",  }, continent = 2, map = 17, blob = 54832, race = 1, points = {} }, 
		["Tomb of the Watchers Digsite"] = { locales = { ["enUS"] = "Tomb of the Watchers Digsite", ["enGB"] = "Tomb of the Watchers Digsite", ["deDE"] = "Ausgrabungsstätte am Grab der Behüter", ["esES"] = "Excavación de la Tumba de los Vigías", ["esMX"] = "Excavación de la Tumba de los Vigías", ["frFR"] = "Site de fouilles du tombeau des Gardiens", ["ruRU"] = "Гробница Стражей - раскопки", ["koKR"] = "감시자의 무덤 발굴현장", ["zhTW"] = "看守者之墓挖掘場",  }, continent = 2, map = 17, blob = 54834, race = 1, points = {} }, 
		["Uldaman Entrance Digsite"] = { locales = { ["enUS"] = "Uldaman Entrance Digsite", ["enGB"] = "Uldaman Entrance Digsite", ["deDE"] = "Ausgrabungsstätte am Eingang nach Uldaman", ["esES"] = "Excavación de la Entrada de Uldaman", ["esMX"] = "Excavación de la Entrada de Uldaman", ["frFR"] = "Site de fouilles de l'entrée d'Uldaman", ["ruRU"] = "Вход в Ульдаман - раскопки", ["koKR"] = "울다만 입구 발굴현장", ["zhTW"] = "奧達曼挖掘場",  }, continent = 2, map = 17, blob = 54838, race = 1, points = {} }, 
		["Sunken Temple Digsite"] = { locales = { ["enUS"] = "Sunken Temple Digsite", ["enGB"] = "Sunken Temple Digsite", ["deDE"] = "Ausgrabungsstätte des Versunkenen Tempels", ["esES"] = "Excavación del Templo Sumergido", ["esMX"] = "Excavación del Templo Sumergido", ["frFR"] = "Site de fouilles du temple Englouti", ["ruRU"] = "Затонувший храм - раскопки", ["koKR"] = "가라앉은 사원 발굴현장", ["zhTW"] = "沉沒的神廟挖掘場",  }, continent = 2, map = 38, blob = 54862, race = 8, points = {} }, 
		["Misty Reed Fossil Bank"] = { locales = { ["enUS"] = "Misty Reed Fossil Bank", ["enGB"] = "Misty Reed Fossil Bank", ["deDE"] = "Fossilienbank am Nebelschilfstrand", ["esES"] = "Banco de fósiles de Juncobruma", ["esMX"] = "Banco de fósiles de Juncobruma", ["frFR"] = "Banc de fossiles de Brumejonc", ["ruRU"] = "Тростниковый берег - ископаемая земля", ["koKR"] = "안개갈대 화석 강둑", ["zhTW"] = "蘆葦古河岸",  }, continent = 2, map = 38, blob = 54864, race = 3, points = {} }, 
		["Twilight Grove Digsite"] = { locales = { ["enUS"] = "Twilight Grove Digsite", ["enGB"] = "Twilight Grove Digsite", ["deDE"] = "Ausgrabungsstätte am Zwielichtshain", ["esES"] = "Excavación de la Arboleda del Crepúsculo", ["esMX"] = "Excavación de la Arboleda del Crepúsculo", ["frFR"] = "Site de fouilles du bosquet Crépusculaire", ["ruRU"] = "Мглистая роща - раскопки", ["koKR"] = "황혼의 숲 발굴현장", ["zhTW"] = "暮光森林挖掘場",  }, continent = 2, map = 34, blob = 55350, race = 4, points = {} }, 
		["Vul'Gol Fossil Bank"] = { locales = { ["enUS"] = "Vul'Gol Fossil Bank", ["enGB"] = "Vul'Gol Fossil Bank", ["deDE"] = "Fossilienbank von Vul'Gol", ["esES"] = "Banco de fósiles de Vul'Gol", ["esMX"] = "Banco de fósiles de Vul'Gol", ["frFR"] = "Banc de fossiles de Vul'Gol", ["ruRU"] = "Вул'Гол - ископаемая земля", ["koKR"] = "벌골 화석 강둑", ["zhTW"] = "沃古爾古河岸",  }, continent = 2, map = 34, blob = 55352, race = 3, points = {} }, 
		["Nazj'vel Digsite"] = { locales = { ["enUS"] = "Nazj'vel Digsite", ["enGB"] = "Nazj'vel Digsite", ["deDE"] = "Ausgrabungsstätte von Nazj'vel", ["esES"] = "Excavación de Nazj'vel", ["esMX"] = "Excavación de Nazj'vel", ["frFR"] = "Site de fouilles Nazj'vel", ["ruRU"] = "Назж'вел - раскопки", ["koKR"] = "나즈벨 발굴현장", ["zhTW"] = "納傑韋爾挖掘場",  }, continent = 1, map = 42, blob = 55354, race = 4, points = {} }, 
		["Zoram Strand Digsite"] = { locales = { ["enUS"] = "Zoram Strand Digsite", ["enGB"] = "Zoram Strand Digsite", ["deDE"] = "Ausgrabungsstätte am Zoramstrand", ["esES"] = "Excavación de La Ensenada de Zoram", ["esMX"] = "Excavación de La Ensenada de Zoram", ["frFR"] = "Site de fouilles de la grève de Zoram", ["ruRU"] = "Зорамское взморье - раскопки", ["koKR"] = "조람 해안 발굴현장", ["zhTW"] = "佐拉姆海岸挖掘場",  }, continent = 1, map = 43, blob = 55356, race = 4, points = {} }, 
		["Ruins of Ordil'Aran"] = { locales = { ["enUS"] = "Ruins of Ordil'Aran", ["enGB"] = "Ruins of Ordil'Aran", ["deDE"] = "Ruinen von Ordil'Aran", ["esES"] = "Las Ruinas de Ordil'Aran", ["esMX"] = "Las Ruinas de Ordil'Aran", ["frFR"] = "Ruines d'Ordil'Aran", ["ruRU"] = "Руины Ордил'Арана", ["koKR"] = "오르딜아란의 폐허", ["zhTW"] = "奧迪拉蘭廢墟",  }, continent = 1, map = 43, blob = 55398, race = 4, points = {} }, 
		["Ruins of Stardust"] = { locales = { ["enUS"] = "Ruins of Stardust", ["enGB"] = "Ruins of Stardust", ["deDE"] = "Sternenstaubruinen", ["esES"] = "Las Ruinas del Polvo Estelar", ["esMX"] = "Las Ruinas del Polvo Estelar", ["frFR"] = "Ruines de Chimétoile", ["ruRU"] = "Руины Звездной Пыли", ["koKR"] = "별가루의 폐허", ["zhTW"] = "星塵廢墟",  }, continent = 1, map = 43, blob = 55400, race = 4, points = {} }, 
		["Forest Song Digsite"] = { locales = { ["enUS"] = "Forest Song Digsite", ["enGB"] = "Forest Song Digsite", ["deDE"] = "Ausgrabungsstätte von Waldeslied", ["esES"] = "Excavación de la Canción del Bosque", ["esMX"] = "Excavación de la Canción del Bosque", ["frFR"] = "Site de fouilles de Chant des forêts", ["ruRU"] = "Лесная Песнь - раскопки", ["koKR"] = "숲의 노래 발굴현장", ["zhTW"] = "林歌神殿挖掘場",  }, continent = 1, map = 43, blob = 55402, race = 4, points = {} }, 
		["Stonetalon Peak"] = { locales = { ["enUS"] = "Stonetalon Peak", ["enGB"] = "Stonetalon Peak", ["deDE"] = "Steinkrallengipfel", ["esES"] = "Cima del Espolón", ["esMX"] = "Cima del Espolón", ["frFR"] = "Pic des Serres-Rocheuses", ["ruRU"] = "Пик Каменного Когтя", ["koKR"] = "돌발톱 봉우리", ["zhTW"] = "石爪峰",  }, continent = 1, map = 81, blob = 55404, race = 4, points = {} }, 
		["Ruins of Eldre'Thar"] = { locales = { ["enUS"] = "Ruins of Eldre'Thar", ["enGB"] = "Ruins of Eldre'Thar", ["deDE"] = "Ruinen von Eldre'Thar", ["esES"] = "Ruinas de Eldre'thar", ["esMX"] = "Ruinas de Eldre'thar", ["frFR"] = "Ruines d'Eldre'Thar", ["ruRU"] = "Руины Эльдре'тара", ["koKR"] = "엘드레타르 폐허", ["zhTW"] = "艾爾德雷薩廢墟",  }, continent = 1, map = 81, blob = 55406, race = 4, points = {} }, 
		["Unearthed Grounds"] = { locales = { ["enUS"] = "Unearthed Grounds", ["enGB"] = "Unearthed Grounds", ["deDE"] = "Die Grabstätte", ["esES"] = "Campos Desenterrados", ["esMX"] = "Campos Desenterrados", ["frFR"] = "Terres Exhumées", ["ruRU"] = "Место раскопок", ["koKR"] = "발굴된 땅", ["zhTW"] = "掘出的遺址",  }, continent = 1, map = 81, blob = 55408, race = 3, points = {} }, 
		["Bael Modan Digsite"] = { locales = { ["enUS"] = "Bael Modan Digsite", ["enGB"] = "Bael Modan Digsite", ["deDE"] = "Ausgrabungsstätte von Bael Modan", ["esES"] = "Excavación de Bael Modan", ["esMX"] = "Excavación de Bael Modan", ["frFR"] = "Site de fouilles de Bael Modan", ["ruRU"] = "Бейл Модан - раскопки", ["koKR"] = "바엘 모단 발굴현장", ["zhTW"] = "巴爾莫丹挖掘場",  }, continent = 1, map = 607, blob = 55410, race = 1, points = {} }, 
		["Ruins of Eldarath"] = { locales = { ["enUS"] = "Ruins of Eldarath", ["enGB"] = "Ruins of Eldarath", ["deDE"] = "Ruinen von Eldarath", ["esES"] = "Ruinas de Eldarath", ["esMX"] = "Ruinas de Eldarath", ["frFR"] = "Ruines d'Eldarath", ["ruRU"] = "Руины Эльдарата", ["koKR"] = "엘다라스 폐허", ["zhTW"] = "埃達拉斯廢墟",  }, continent = 1, map = 181, blob = 55412, race = 4, points = {} }, 
		["Ruins of Arkkoran"] = { locales = { ["enUS"] = "Ruins of Arkkoran", ["enGB"] = "Ruins of Arkkoran", ["deDE"] = "Ruinen von Arkkoran", ["esES"] = "Ruinas de Arkkoran", ["esMX"] = "Ruinas de Arkkoran", ["frFR"] = "Ruines d'Arkkoran", ["ruRU"] = "Руины храма Арккоран", ["koKR"] = "아크코란의 폐허", ["zhTW"] = "亞考蘭廢墟",  }, continent = 1, map = 181, blob = 55414, race = 4, points = {} }, 
		["Lakeridge Highway Fossil Bank"] = { locales = { ["enUS"] = "Lakeridge Highway Fossil Bank", ["enGB"] = "Lakeridge Highway Fossil Bank", ["deDE"] = "Fossilienbank am Uferpfad", ["esES"] = "Banco de fósiles del Camino del Lago", ["esMX"] = "Banco de fósiles del Camino del Lago", ["frFR"] = "Banc de fossiles de la grand-route de la crête du Lac", ["ruRU"] = "Озерный тракт - ископаемая земля", ["koKR"] = "호수마루 오솔길 화석 강둑", ["zhTW"] = "湖邊大道古河岸",  }, continent = 2, map = 36, blob = 55416, race = 3, points = {} }, 
		["Slitherblade Shore Digsite"] = { locales = { ["enUS"] = "Slitherblade Shore Digsite", ["enGB"] = "Slitherblade Shore Digsite", ["deDE"] = "Ausgrabungsstätte am Strand der Zackenkämme", ["esES"] = "Excavación de la Costa Filozante", ["esMX"] = "Excavación de la Costa Filozante", ["frFR"] = "Site de fouilles du rivage des Ondulames", ["ruRU"] = "Берег Скользящего Плавника - раскопки", ["koKR"] = "뱀갈퀴 해안 발굴현장", ["zhTW"] = "滑刃水濱挖掘場",  }, continent = 1, map = 101, blob = 55418, race = 4, points = {} }, 
		["Ethel Rethor Digsite"] = { locales = { ["enUS"] = "Ethel Rethor Digsite", ["enGB"] = "Ethel Rethor Digsite", ["deDE"] = "Ausgrabungsstätte von Ethel Rethor", ["esES"] = "Excavación de Ethel Rethor", ["esMX"] = "Excavación de Ethel Rethor", ["frFR"] = "Site de fouilles d'Ethel Rethor", ["ruRU"] = "Этель-Ретор - раскопки", ["koKR"] = "에텔 레소르 발굴현장", ["zhTW"] = "艾瑟雷索挖掘場",  }, continent = 1, map = 101, blob = 55420, race = 4, points = {} }, 
		["Valley of Bones"] = { locales = { ["enUS"] = "Valley of Bones", ["enGB"] = "Valley of Bones", ["deDE"] = "Tal der Knochen", ["esES"] = "Valle de los Huesos", ["esMX"] = "Valle de los Huesos", ["frFR"] = "Vallée des ossements", ["ruRU"] = "Долина Костей", ["koKR"] = "뼈의 골짜기", ["zhTW"] = "白骨之谷",  }, continent = 1, map = 101, blob = 55422, race = 3, points = {} }, 
		["Mannoroc Coven Digsite"] = { locales = { ["enUS"] = "Mannoroc Coven Digsite", ["enGB"] = "Mannoroc Coven Digsite", ["deDE"] = "Ausgrabungsstätte am Zirkel der Mannoroc", ["esES"] = "Excavación del Aquelarre Mannoroc", ["esMX"] = "Excavación del Aquelarre Mannoroc", ["frFR"] = "Site de fouilles du convent de Mannoroc", ["ruRU"] = "Поле Маннорок - раскопки", ["koKR"] = "만노로크 소굴 발굴현장", ["zhTW"] = "瑪諾洛克集會所挖掘場",  }, continent = 1, map = 101, blob = 55424, race = 4, points = {} }, 
		["Kodo Graveyard"] = { locales = { ["enUS"] = "Kodo Graveyard", ["enGB"] = "Kodo Graveyard", ["deDE"] = "Kodofriedhof", ["esES"] = "Cementerio de Kodos", ["esMX"] = "Cementerio de Kodos", ["frFR"] = "Cimetière des Kodos", ["ruRU"] = "Кладбище кодо", ["koKR"] = "코도 무덤", ["zhTW"] = "科多獸墳場",  }, continent = 1, map = 101, blob = 55426, race = 3, points = {} }, 
		["Sargeron Digsite"] = { locales = { ["enUS"] = "Sargeron Digsite", ["enGB"] = "Sargeron Digsite", ["deDE"] = "Sargerons Ausgrabungsstätte", ["esES"] = "Excavación de Sargeron", ["esMX"] = "Excavación de Sargeron", ["frFR"] = "Site de fouilles de Sargeron", ["ruRU"] = "Саргерон - раскопки", ["koKR"] = "살게론 발굴현장", ["zhTW"] = "薩格隆挖掘場",  }, continent = 1, map = 101, blob = 55428, race = 4, points = {} }, 
		["Red Reaches Fossil Bank"] = { locales = { ["enUS"] = "Red Reaches Fossil Bank", ["enGB"] = "Red Reaches Fossil Bank", ["deDE"] = "Fossilienbank der Roten Weiten", ["esES"] = "Banco de fósiles de Las Costas Rojas", ["esMX"] = "Banco de fósiles de Las Costas Rojas", ["frFR"] = "Banc de fossiles des confins Rouges", ["ruRU"] = "Красные берега - ископаемая земля", ["koKR"] = "붉은 굽이 화석 강둑", ["zhTW"] = "紅色海岸古河岸",  }, continent = 2, map = 19, blob = 55434, race = 3, points = {} }, 
		["Dreadmaul Fossil Field"] = { locales = { ["enUS"] = "Dreadmaul Fossil Field", ["enGB"] = "Dreadmaul Fossil Field", ["deDE"] = "Fossilienfeld am Schreckensfelsen", ["esES"] = "Campo de fósiles Machacamiedo", ["esMX"] = "Campo de fósiles Machacamiedo", ["frFR"] = "Champ de fossiles Cognepeur", ["ruRU"] = "Молот Ужаса - ископаемая почва", ["koKR"] = "우레망치 화석 벌판", ["zhTW"] = "巨槌古原野",  }, continent = 2, map = 19, blob = 55436, race = 3, points = {} }, 
		["Grimsilt Digsite"] = { locales = { ["enUS"] = "Grimsilt Digsite", ["enGB"] = "Grimsilt Digsite", ["deDE"] = "Grimmsilts Ausgrabungsstätte", ["esES"] = "Excavación de Limugre", ["esMX"] = "Excavación de Limugre", ["frFR"] = "Site de fouilles de Crasseboue", ["ruRU"] = "Гримсилт - раскопки", ["koKR"] = "검댕가루 발굴현장", ["zhTW"] = "煤渣挖掘場",  }, continent = 2, map = 28, blob = 55438, race = 1, points = {} }, 
		["Pyrox Flats Digsite"] = { locales = { ["enUS"] = "Pyrox Flats Digsite", ["enGB"] = "Pyrox Flats Digsite", ["deDE"] = "Ausgrabungsstätte der Pyroxebenen", ["esES"] = "Excavación de Llanos de Pirox", ["esMX"] = "Excavación de Llanos de Pirox", ["frFR"] = "Site de fouilles de la plaine de Pyrox", ["ruRU"] = "Пироксовые равнины - раскопки", ["koKR"] = "휘석 평원 발굴현장", ["zhTW"] = "派洛克斯平原挖掘場",  }, continent = 2, map = 28, blob = 55440, race = 1, points = {} }, 
		["Western Ruins of Thaurissan"] = { locales = { ["enUS"] = "Western Ruins of Thaurissan", ["enGB"] = "Western Ruins of Thaurissan", ["deDE"] = "Westliche Ruinen von Thaurissan", ["esES"] = "Ruinas de Thaurissan del Oeste", ["esMX"] = "Ruinas de Thaurissan del Oeste", ["frFR"] = "Ruines de Thaurissan ouest", ["ruRU"] = "Западные руины Тауриссана", ["koKR"] = "타우릿산의 폐허 서부", ["zhTW"] = "索瑞森西部廢墟",  }, continent = 2, map = 29, blob = 55442, race = 1, points = {} }, 
		["Eastern Ruins of Thaurissan"] = { locales = { ["enUS"] = "Eastern Ruins of Thaurissan", ["enGB"] = "Eastern Ruins of Thaurissan", ["deDE"] = "Östliche Ruinen von Thaurissan", ["esES"] = "Ruinas de Thaurissan del Este", ["esMX"] = "Ruinas de Thaurissan del Este", ["frFR"] = "Ruines est de Thaurissan", ["ruRU"] = "Восточные руины Тауриссана", ["koKR"] = "타우릿산의 폐허 동부", ["zhTW"] = "索瑞森東部廢墟",  }, continent = 2, map = 29, blob = 55444, race = 1, points = {} }, 
		["Terror Wing Fossil Field"] = { locales = { ["enUS"] = "Terror Wing Fossil Field", ["enGB"] = "Terror Wing Fossil Field", ["deDE"] = "Fossilienfeld am Schreckenspfad", ["esES"] = "Campo de fósiles del Ala del Terror", ["esMX"] = "Campo de fósiles del Ala del Terror", ["frFR"] = "Champ de fossiles de l'Aile de la terreur", ["ruRU"] = "Тропа Крылатого Ужаса - ископаемая почва", ["koKR"] = "공포의 날개 화석 벌판", ["zhTW"] = "龍翼小徑古原野",  }, continent = 2, map = 29, blob = 55446, race = 3, points = {} }, 
		["Zul'Mashar Digsite"] = { locales = { ["enUS"] = "Zul'Mashar Digsite", ["enGB"] = "Zul'Mashar Digsite", ["deDE"] = "Ausgrabungsstätte von Zul'Mashar", ["esES"] = "Excavación de Zul'Mashar", ["esMX"] = "Excavación de Zul'Mashar", ["frFR"] = "Site de fouilles de Zul'Mashar", ["ruRU"] = "Зул'Машар - раскопки", ["koKR"] = "줄마샤르 발굴현장", ["zhTW"] = "祖爾瑪夏挖掘場",  }, continent = 2, map = 23, blob = 55448, race = 8, points = {} }, 
		["Quel'Lithien Lodge Digsite"] = { locales = { ["enUS"] = "Quel'Lithien Lodge Digsite", ["enGB"] = "Quel'Lithien Lodge Digsite", ["deDE"] = "Ausgrabungsstätte bei der Jagdhütte Quel'Lithien", ["esES"] = "Excavación del Refugio Quel'Lithien", ["esMX"] = "Excavación del Refugio Quel'Lithien", ["frFR"] = "Site de fouilles du gîte de Quel'Lithien", ["ruRU"] = "Сторожка Кель'Литиен - раскопки", ["koKR"] = "쿠엘리시엔 오두막 발굴현장", ["zhTW"] = "奎爾林斯小屋挖掘場",  }, continent = 2, map = 23, blob = 55450, race = 4, points = {} }, 
		["Infectis Scar Fossil Field"] = { locales = { ["enUS"] = "Infectis Scar Fossil Field", ["enGB"] = "Infectis Scar Fossil Field", ["deDE"] = "Fossilienfeld der Infektnarbe", ["esES"] = "Campo de fósiles de La Cicatriz Purulenta", ["esMX"] = "Campo de fósiles de La Cicatriz Purulenta", ["frFR"] = "Champ de fossiles de la Balafre infecte", ["ruRU"] = "Чумной овраг - ископаемая почва", ["koKR"] = "오염의 흉터 화석 벌판", ["zhTW"] = "魔刃之痕古原野",  }, continent = 2, map = 23, blob = 55452, race = 3, points = {} }, 
		["Eastern Zul'Kunda Digsite"] = { locales = { ["enUS"] = "Eastern Zul'Kunda Digsite", ["enGB"] = "Eastern Zul'Kunda Digsite", ["deDE"] = "Östliche Ausgrabungsstätte von Zul'Kunda", ["esES"] = "Excavación de Zul'Kunda del Este", ["esMX"] = "Excavación de Zul'Kunda del Este", ["frFR"] = "Site de fouilles de Zul'Kunda est", ["ruRU"] = "Восточная Зул'Кунда - раскопки", ["koKR"] = "동부 줄쿤다 발굴현장", ["zhTW"] = "祖昆達東部挖掘場",  }, continent = 2, map = 37, blob = 55454, race = 8, points = {} }, 
		["Western Zul'Kunda Digsite"] = { locales = { ["enUS"] = "Western Zul'Kunda Digsite", ["enGB"] = "Western Zul'Kunda Digsite", ["deDE"] = "Westliche Ausgrabungsstätte von Zul'Kunda", ["esES"] = "Excavación de Zul'Kunda del Oeste", ["esMX"] = "Excavación de Zul'Kunda del Oeste", ["frFR"] = "Site de fouilles de Zul'Kunda ouest", ["ruRU"] = "Западная Зул'Кунда - раскопки", ["koKR"] = "서부 줄쿤다 발굴현장", ["zhTW"] = "祖昆達西部挖掘場",  }, continent = 2, map = 37, blob = 55456, race = 8, points = {} }, 
		["Bal'lal Ruins Digsite"] = { locales = { ["enUS"] = "Bal'lal Ruins Digsite", ["enGB"] = "Bal'lal Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Bal'lal", ["esES"] = "Excavación de la Ruina de Bal'lal", ["esMX"] = "Excavación de la Ruina de Bal'lal", ["frFR"] = "Site de fouilles des ruines de Bal'lal", ["ruRU"] = "Руины Бал'лал - раскопки", ["koKR"] = "발랄 폐허 발굴현장", ["zhTW"] = "巴拉爾廢墟挖掘場",  }, continent = 2, map = 37, blob = 55458, race = 8, points = {} }, 
		["Balia'mah Digsite"] = { locales = { ["enUS"] = "Balia'mah Digsite", ["enGB"] = "Balia'mah Digsite", ["deDE"] = "Ausgrabungsstätte von Balia'mah", ["esES"] = "Excavación de Balia'mah", ["esMX"] = "Excavación de Balia'mah", ["frFR"] = "Site de fouilles de Balia'mah", ["ruRU"] = "Балиа'ма - раскопки", ["koKR"] = "발리아마 발굴현장", ["zhTW"] = "巴里亞曼挖掘場",  }, continent = 2, map = 37, blob = 55460, race = 8, points = {} }, 
		["Ziata'jai Digsite"] = { locales = { ["enUS"] = "Ziata'jai Digsite", ["enGB"] = "Ziata'jai Digsite", ["deDE"] = "Ausgrabungsstätte von Ziata'jai", ["esES"] = "Excavación de Ziata'jai", ["esMX"] = "Excavación de Ziata'jai", ["frFR"] = "Site de fouilles de Ziata'jai", ["ruRU"] = "Зиата'джаи - раскопки", ["koKR"] = "지아타자이 발굴현장", ["zhTW"] = "贊塔加挖掘場",  }, continent = 2, map = 37, blob = 55462, race = 8, points = {} }, 
		["Eastern Zul'Mamwe Digsite"] = { locales = { ["enUS"] = "Eastern Zul'Mamwe Digsite", ["enGB"] = "Eastern Zul'Mamwe Digsite", ["deDE"] = "Östliche Ausgrabungsstätte von Zul'Mamwe", ["esES"] = "Excavación de Zul'Mamwe del Este", ["esMX"] = "Excavación de Zul'Mamwe del Este", ["frFR"] = "Site de fouilles de Zul'Mamwe est", ["ruRU"] = "Восточный Зул'Мамве - раскопки", ["koKR"] = "동부 줄맘웨 발굴현장", ["zhTW"] = "祖瑪維東部挖掘場",  }, continent = 2, map = 37, blob = 55464, race = 8, points = {} }, 
		["Western Zul'Mamwe Digsite"] = { locales = { ["enUS"] = "Western Zul'Mamwe Digsite", ["enGB"] = "Western Zul'Mamwe Digsite", ["deDE"] = "Westliche Ausgrabungsstätte von Zul'Mamwe", ["esES"] = "Excavación de Zul'Mamwe del Oeste", ["esMX"] = "Excavación de Zul'Mamwe del Oeste", ["frFR"] = "Site de fouilles de Zul'Mamwe ouest", ["ruRU"] = "Западный Зул'Мамве - раскопки", ["koKR"] = "서부 줄맘웨 발굴현장", ["zhTW"] = "祖瑪維西部挖掘場",  }, continent = 2, map = 37, blob = 55466, race = 8, points = {} }, 
		["Savage Coast Raptor Fields"] = { locales = { ["enUS"] = "Savage Coast Raptor Fields", ["enGB"] = "Savage Coast Raptor Fields", ["deDE"] = "Raptorfelder der Ungezähmten Küste", ["esES"] = "Campos de raptores de La Costa Salvaje", ["esMX"] = "Campos de raptores de La Costa Salvaje", ["frFR"] = "Champs de raptors de la côte Sauvage", ["ruRU"] = "Гибельный берег, поля ящеров", ["koKR"] = "폭풍 해안 랩터 벌판", ["zhTW"] = "野人海岸迅猛龍平原",  }, continent = 2, map = 37, blob = 55468, race = 3, points = {} }, 
		["Ruins of Aboraz"] = { locales = { ["enUS"] = "Ruins of Aboraz", ["enGB"] = "Ruins of Aboraz", ["deDE"] = "Ruinen von Aboraz", ["esES"] = "Ruinas de Aboraz", ["esMX"] = "Ruinas de Aboraz", ["frFR"] = "Ruines d'Aboraz", ["ruRU"] = "Руины Абораза", ["koKR"] = "아보라즈의 폐허", ["zhTW"] = "阿博拉茲廢墟",  }, continent = 2, map = 673, blob = 55470, race = 8, points = {} }, 
		["Ruins of Jubuwal"] = { locales = { ["enUS"] = "Ruins of Jubuwal", ["enGB"] = "Ruins of Jubuwal", ["deDE"] = "Ruinen von Jubuwal", ["esES"] = "Ruinas de Jubuwal", ["esMX"] = "Ruinas de Jubuwal", ["frFR"] = "Ruines de Jubuwal", ["ruRU"] = "Руины Жубуваля", ["koKR"] = "주부왈의 폐허", ["zhTW"] = "朱布瓦爾廢墟",  }, continent = 2, map = 673, blob = 55472, race = 8, points = {} }, 
		["Gurubashi Arena Digsite"] = { locales = { ["enUS"] = "Gurubashi Arena Digsite", ["enGB"] = "Gurubashi Arena Digsite", ["deDE"] = "Ausgrabungsstätte an der Arena der Gurubashiarena", ["esES"] = "Excavación de la Arena Gurubashi", ["esMX"] = "Excavación de la Arena Gurubashi", ["frFR"] = "Site de fouilles de l'arène des Gurubashi", ["ruRU"] = "Арена Гурубаши - раскопки", ["koKR"] = "구루바시 투기장 발굴현장", ["zhTW"] = "古拉巴什競技場挖掘場",  }, continent = 2, map = 673, blob = 55474, race = 8, points = {} }, 
		["Nek'mani Wellspring Digsite"] = { locales = { ["enUS"] = "Nek'mani Wellspring Digsite", ["enGB"] = "Nek'mani Wellspring Digsite", ["deDE"] = "Ausgrabungsstätte am Nek'maniquellbrunnen", ["esES"] = "Excavación del Manantial Nek'mani", ["esMX"] = "Excavación del Manantial Nek'mani", ["frFR"] = "Site de fouilles de la fontaine des Nek'mani", ["ruRU"] = "Родник Нек'Мани - раскопки", ["koKR"] = "네크마니 수원지 발굴현장", ["zhTW"] = "納克邁尼聖泉挖掘場",  }, continent = 2, map = 673, blob = 55476, race = 8, points = {} }, 
		["Felstone Fossil Field"] = { locales = { ["enUS"] = "Felstone Fossil Field", ["enGB"] = "Felstone Fossil Field", ["deDE"] = "Teufelssteinfossilienfeld", ["esES"] = "Campo de fósiles Piedramácula", ["esMX"] = "Campo de fósiles Piedramácula", ["frFR"] = "Champ de fossiles de Gangrepierre", ["ruRU"] = "Поле Джанис - ископаемая почва", ["koKR"] = "펠스톤 화석 벌판", ["zhTW"] = "費爾斯通古原野",  }, continent = 2, map = 22, blob = 55478, race = 3, points = {} }, 
		["Northridge Fossil Filed"] = { locales = { ["enUS"] = "Northridge Fossil Filed", ["enGB"] = "Northridge Fossil Filed", ["deDE"] = "Fossilienfeld am Nordkamm", ["esES"] = "Campo de fósiles Crestanorte", ["esMX"] = "Campo de fósiles Crestanorte", ["frFR"] = "Champ de fossiles de la crête du Nord", ["ruRU"] = "Северный  Кряж - ископаемая почва", ["koKR"] = "북마루 화석 벌판", ["zhTW"] = "北山古原野",  }, continent = 2, map = 22, blob = 55480, race = 3, points = {} }, 
		["Andorhal Fossil Bank"] = { locales = { ["enUS"] = "Andorhal Fossil Bank", ["enGB"] = "Andorhal Fossil Bank", ["deDE"] = "Fossilienbank von Andorhal", ["esES"] = "Banco de fósiles de Andorhal", ["esMX"] = "Banco de fósiles de Andorhal", ["frFR"] = "Banc de fossiles d'Andorhal", ["ruRU"] = "Андорал - ископаемая земля", ["koKR"] = "안돌할 화석 강둑", ["zhTW"] = "安多哈爾古河岸",  }, continent = 2, map = 22, blob = 55482, race = 3, points = {} }, 
		["Wyrmbog Fossil Field"] = { locales = { ["enUS"] = "Wyrmbog Fossil Field", ["enGB"] = "Wyrmbog Fossil Field", ["deDE"] = "Fossilienfeld des Drachensumpfes", ["esES"] = "Campo de fósiles de Ciénaga de Fuego", ["esMX"] = "Campo de fósiles de Ciénaga de Fuego", ["frFR"] = "Champ de fossiles de Tourbière du Ver", ["ruRU"] = "Драконьи топи - ископаемая почва", ["koKR"] = "용의 둥지 화석 벌판", ["zhTW"] = "巨龍泥沼古原野",  }, continent = 1, map = 141, blob = 55755, race = 3, points = {} }, 
		["Quagmire Fossil Field"] = { locales = { ["enUS"] = "Quagmire Fossil Field", ["enGB"] = "Quagmire Fossil Field", ["deDE"] = "Fossilienfeld im Morast", ["esES"] = "Campo de fósiles de El Lodazal", ["esMX"] = "Campo de fósiles de El Lodazal", ["frFR"] = "Champ de fossiles du Bourbier", ["ruRU"] = "Трясина - ископаемая почва", ["koKR"] = "먼지 수렁 화석 벌판", ["zhTW"] = "泥潭沼澤古原野",  }, continent = 1, map = 141, blob = 55757, race = 3, points = {} }, 
		["Dire Maul Digsite"] = { locales = { ["enUS"] = "Dire Maul Digsite", ["enGB"] = "Dire Maul Digsite", ["deDE"] = "Ausgrabungsstätte des Düsterbruchs", ["esES"] = "Excavación de La Masacre", ["esMX"] = "Excavación de La Masacre", ["frFR"] = "Site de fouilles de Hache-Tripes", ["ruRU"] = "Забытый Город - раскопки", ["koKR"] = "혈투의 전장 발굴현장", ["zhTW"] = "厄運之槌挖掘場",  }, continent = 1, map = 121, blob = 56327, race = 4, points = {} }, 
		["Broken Commons Digsite"] = { locales = { ["enUS"] = "Broken Commons Digsite", ["enGB"] = "Broken Commons Digsite", ["deDE"] = "Ausgrabungsstätte der Zerstörten Allmende", ["esES"] = "Excavación de la Ágora", ["esMX"] = "Excavación de la Ágora", ["frFR"] = "Site de fouilles des communs en ruine", ["ruRU"] = "Разоренные земли - раскопки", ["koKR"] = "파괴된 광장 발굴현장", ["zhTW"] = "平民區廢墟挖掘場",  }, continent = 1, map = 121, blob = 56329, race = 4, points = {} }, 
		["Ravenwind Digsite"] = { locales = { ["enUS"] = "Ravenwind Digsite", ["enGB"] = "Ravenwind Digsite", ["deDE"] = "Ausgrabungsstätte von Rabenwind", ["esES"] = "Excavación de las Ruinas de Viento Azabache", ["esMX"] = "Excavación de las Ruinas de Viento Azabache", ["frFR"] = "Site de fouilles de Vent-du-Corbeau", ["ruRU"] = "Яростный Ветер - раскопки", ["koKR"] = "까마귀바람 발굴현장", ["zhTW"] = "鴉風挖掘場",  }, continent = 1, map = 121, blob = 56331, race = 4, points = {} }, 
		["Oneiros Digsite"] = { locales = { ["enUS"] = "Oneiros Digsite", ["enGB"] = "Oneiros Digsite", ["deDE"] = "Ausgrabungsstätte von Oneiros", ["esES"] = "Excavación de Oneiros", ["esMX"] = "Excavación de Oneiros", ["frFR"] = "Site de fouilles d'Oneiros", ["ruRU"] = "Онейрос - раскопки", ["koKR"] = "오네이로스 발굴현장", ["zhTW"] = "奧奈羅斯挖掘場",  }, continent = 1, map = 121, blob = 56333, race = 4, points = {} }, 
		["Solarsal Digsite"] = { locales = { ["enUS"] = "Solarsal Digsite", ["enGB"] = "Solarsal Digsite", ["deDE"] = "Ausgrabungsstätte von Solarsal", ["esES"] = "Excavación de Solarsal", ["esMX"] = "Excavación de Solarsal", ["frFR"] = "Site de fouilles de Solarsal", ["ruRU"] = "Соларсаль - раскопки", ["koKR"] = "솔라살 발굴현장", ["zhTW"] = "索蘭薩爾挖掘場",  }, continent = 1, map = 121, blob = 56335, race = 4, points = {} }, 
		["Darkmist Digsite"] = { locales = { ["enUS"] = "Darkmist Digsite", ["enGB"] = "Darkmist Digsite", ["deDE"] = "Graunebelausgrabungsstätte", ["esES"] = "Excavación de Niebla Negra", ["esMX"] = "Excavación de Niebla Negra", ["frFR"] = "Site de fouilles de Sombrebrume", ["ruRU"] = "Мглистая пещера - раскопки", ["koKR"] = "암흑안개 발굴현장", ["zhTW"] = "暗霧挖掘場",  }, continent = 1, map = 121, blob = 56337, race = 4, points = {} }, 
		["South Isildien Digsite"] = { locales = { ["enUS"] = "South Isildien Digsite", ["enGB"] = "South Isildien Digsite", ["deDE"] = "Ausgrabungsstätte von Südisildien", ["esES"] = "Excavación de Isildien sur", ["esMX"] = "Excavación de Isildien sur", ["frFR"] = "Site de fouilles d'Isildien sud", ["ruRU"] = "Южный Исильдиэн - раскопки", ["koKR"] = "이실디엔 남부 발굴현장", ["zhTW"] = "伊斯迪爾南部挖掘場",  }, continent = 1, map = 121, blob = 56339, race = 4, points = {} }, 
		["North Isildien Digsite"] = { locales = { ["enUS"] = "North Isildien Digsite", ["enGB"] = "North Isildien Digsite", ["deDE"] = "Ausgrabungsstätte von Nordisildien", ["esES"] = "Excavación de Isildien norte", ["esMX"] = "Excavación de Isildien norte", ["frFR"] = "Site de fouilles d'Isildien nord", ["ruRU"] = "Северный Исильдиэн - раскопки", ["koKR"] = "이실디엔 북부 발굴현장", ["zhTW"] = "伊斯迪爾北部挖掘場",  }, continent = 1, map = 121, blob = 56341, race = 4, points = {} }, 
		["Constellas Digsite"] = { locales = { ["enUS"] = "Constellas Digsite", ["enGB"] = "Constellas Digsite", ["deDE"] = "Ausgrabungsstätte von Constellas", ["esES"] = "Excavación de Constellas", ["esMX"] = "Excavación de Constellas", ["frFR"] = "Site de fouilles de Constellas", ["ruRU"] = "Констеллас - раскопки", ["koKR"] = "콘스텔라스 발굴현장", ["zhTW"] = "克斯特拉斯挖掘場",  }, continent = 1, map = 182, blob = 56343, race = 4, points = {} }, 
		["Morlos'Aran Digsite"] = { locales = { ["enUS"] = "Morlos'Aran Digsite", ["enGB"] = "Morlos'Aran Digsite", ["deDE"] = "Ausgrabungsstätte von Morlos'Aran", ["esES"] = "Excavación de Morlos'Aran", ["esMX"] = "Excavación de Morlos'Aran", ["frFR"] = "Site de fouilles de Morlos'Aran", ["ruRU"] = "Морлос'Аран - раскопки", ["koKR"] = "모를로스아란 발굴현장", ["zhTW"] = "莫洛亞藍挖掘場",  }, continent = 1, map = 182, blob = 56345, race = 4, points = {} }, 
		["Jaedenar Digsite"] = { locales = { ["enUS"] = "Jaedenar Digsite", ["enGB"] = "Jaedenar Digsite", ["deDE"] = "Ausgrabungsstätte von Jaedenar", ["esES"] = "Excavación de Jaedenar", ["esMX"] = "Excavación de Jaedenar", ["frFR"] = "Site de fouilles de Jaedenar", ["ruRU"] = "Джеденар - раскопки", ["koKR"] = "제데나르 발굴현장", ["zhTW"] = "加德納爾挖掘場",  }, continent = 1, map = 182, blob = 56347, race = 4, points = {} }, 
		["Ironwood Digsite"] = { locales = { ["enUS"] = "Ironwood Digsite", ["enGB"] = "Ironwood Digsite", ["deDE"] = "Eisenholzausgrabungsstätte", ["esES"] = "Excavación de maderaférrea", ["esMX"] = "Excavación de maderaférrea", ["frFR"] = "Site de fouilles bois-de-fer", ["ruRU"] = "Железнолесья - раскопки", ["koKR"] = "강철나무 발굴현장", ["zhTW"] = "鐵木挖掘場",  }, continent = 1, map = 182, blob = 56349, race = 4, points = {} }, 
		["Lake Kel'Theril Digsite"] = { locales = { ["enUS"] = "Lake Kel'Theril Digsite", ["enGB"] = "Lake Kel'Theril Digsite", ["deDE"] = "Ausgrabungsstätte des Kel'Therilsees", ["esES"] = "Excavación del Lago Kel'Theril", ["esMX"] = "Excavación del Lago Kel'Theril", ["frFR"] = "Site de fouilles du lac Kel'Theril", ["ruRU"] = "Озеро Кел'Терил - раскопки", ["koKR"] = "켈테릴 호수 발굴현장", ["zhTW"] = "凱斯利爾湖挖掘場",  }, continent = 1, map = 281, blob = 56351, race = 4, points = {} }, 
		["Owl Wing Thicket Digsite"] = { locales = { ["enUS"] = "Owl Wing Thicket Digsite", ["enGB"] = "Owl Wing Thicket Digsite", ["deDE"] = "Ausgrabungsstätte des Eulenflügeldickichts", ["esES"] = "Excavación del Matorral del Ala del Búho", ["esMX"] = "Excavación del Matorral del Ala del Búho", ["frFR"] = "Site de fouilles du fourré de l'Aile de la chouette", ["ruRU"] = "Совиная чаща - раскопки", ["koKR"] = "올빼미날개 숲 발굴현장", ["zhTW"] = "梟翼樹叢挖掘場",  }, continent = 1, map = 281, blob = 56354, race = 4, points = {} }, 
		["Frostwhisper Gorge Digsite"] = { locales = { ["enUS"] = "Frostwhisper Gorge Digsite", ["enGB"] = "Frostwhisper Gorge Digsite", ["deDE"] = "Ausgrabungsstätte der Frosthauchschlucht", ["esES"] = "Excavación del Cañón Levescarcha", ["esMX"] = "Excavación del Cañón Levescarcha", ["frFR"] = "Site de fouilles du Blanc murmure", ["ruRU"] = "Теснина Ледяного Шепота - раскопки", ["koKR"] = "서리속삭임 골짜기 발굴현장", ["zhTW"] = "霜語峽谷挖掘場",  }, continent = 1, map = 281, blob = 56356, race = 4, points = {} }, 
		["Fields of Blood Fossil Bank"] = { locales = { ["enUS"] = "Fields of Blood Fossil Bank", ["enGB"] = "Fields of Blood Fossil Bank", ["deDE"] = "Fossilienbank der Felder des Blutes", ["esES"] = "Banco de fósiles de los Campos de Sangre", ["esMX"] = "Banco de fósiles de los Campos de Sangre", ["frFR"] = "Banc de fossiles des champs du Sang", ["ruRU"] = "Кровавые поля - ископаемая земля", ["koKR"] = "피의 들판 화석 강둑", ["zhTW"] = "鮮血草原古河岸",  }, continent = 1, map = 607, blob = 56358, race = 3, points = {} }, 
		["Nightmare Scar Digsite"] = { locales = { ["enUS"] = "Nightmare Scar Digsite", ["enGB"] = "Nightmare Scar Digsite", ["deDE"] = "Ausgrabungsstätte der Alptraumnarbe", ["esES"] = "Excavación del Paraje Pesadilla", ["esMX"] = "Excavación del Paraje Pesadilla", ["frFR"] = "Site de fouilles de la balafre du Cauchemar", ["ruRU"] = "Ров Кошмаров - раскопки", ["koKR"] = "악몽의 흉터 발굴현장", ["zhTW"] = "惡夢之痕挖掘場",  }, continent = 1, map = 607, blob = 56362, race = 4, points = {} }, 
		["Zul'Farrak Digsite"] = { locales = { ["enUS"] = "Zul'Farrak Digsite", ["enGB"] = "Zul'Farrak Digsite", ["deDE"] = "Ausgrabungsstätte von Zul'Farrak", ["esES"] = "Excavación de Zul'Farrak", ["esMX"] = "Excavación de Zul'Farrak", ["frFR"] = "Site de fouilles de Zul'Farrak", ["ruRU"] = "Зул'Фаррак - раскопки", ["koKR"] = "줄파락 발굴현장", ["zhTW"] = "祖爾法拉克挖掘場",  }, continent = 1, map = 161, blob = 56364, race = 8, points = {} }, 
		["Broken Pillar Digsite"] = { locales = { ["enUS"] = "Broken Pillar Digsite", ["enGB"] = "Broken Pillar Digsite", ["deDE"] = "Ausgrabungsstätte der Zerbrochenen Säule", ["esES"] = "Excavación del Pilar Partido", ["esMX"] = "Excavación del Pilar Partido", ["frFR"] = "Site de fouilles du pilier brisé", ["ruRU"] = "Разбитая Колонна - раскопки", ["koKR"] = "무너진 기둥 발굴현장", ["zhTW"] = "破碎石柱挖掘場",  }, continent = 1, map = 161, blob = 56367, race = 8, points = {} }, 
		["Eastmoon Ruins Digsite"] = { locales = { ["enUS"] = "Eastmoon Ruins Digsite", ["enGB"] = "Eastmoon Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ostmondruinen", ["esES"] = "Excavación de las Ruinas de Lunaeste", ["esMX"] = "Excavación de las Ruinas de Lunaeste", ["frFR"] = "Site de fouilles des ruines d'Estelune", ["ruRU"] = "Руины Восточной Луны - раскопки", ["koKR"] = "동쪽 달 폐허 발굴현장", ["zhTW"] = "東月廢墟挖掘場",  }, continent = 1, map = 161, blob = 56369, race = 8, points = {} }, 
		["Southmoon Ruins Digsite"] = { locales = { ["enUS"] = "Southmoon Ruins Digsite", ["enGB"] = "Southmoon Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Südmondruinen", ["esES"] = "Excavación de las Ruinas de Lunasur", ["esMX"] = "Excavación de las Ruinas de Lunasur", ["frFR"] = "Site de fouilles des ruines de Sudelune", ["ruRU"] = "Руины Южной Луны - раскопки", ["koKR"] = "남쪽 달 폐허 발굴현장", ["zhTW"] = "南月廢墟挖掘場",  }, continent = 1, map = 161, blob = 56371, race = 8, points = {} }, 
		["Dunemaul Fossil Ridge"] = { locales = { ["enUS"] = "Dunemaul Fossil Ridge", ["enGB"] = "Dunemaul Fossil Ridge", ["deDE"] = "Fossilienkamm der Dünenbrecher", ["esES"] = "Cresta de fósiles de Machacaduna", ["esMX"] = "Cresta de fósiles de Machacaduna", ["frFR"] = "Crête de fossiles des Cognedunes", ["ruRU"] = "Песчаный Молот - ископаемая гряда", ["koKR"] = "모래망치 화석 마루", ["zhTW"] = "砂槌古山脊",  }, continent = 1, map = 161, blob = 56373, race = 3, points = {} }, 
		["Abyssal Sands Fossil Ridge"] = { locales = { ["enUS"] = "Abyssal Sands Fossil Ridge", ["enGB"] = "Abyssal Sands Fossil Ridge", ["deDE"] = "Fossilienkamm der Ewigen Sande", ["esES"] = "Cresta de fósiles de las Arenas Abisales", ["esMX"] = "Cresta de fósiles de las Arenas Abisales", ["frFR"] = "Crête de fossiles du désert Abysséen", ["ruRU"] = "Безбрежные пески - ископаемая гряда", ["koKR"] = "끝없는 사막 화석 마루", ["zhTW"] = "深沙平原古山脊",  }, continent = 1, map = 161, blob = 56375, race = 3, points = {} }, 
		["Lower Lakkari Tar Pits"] = { locales = { ["enUS"] = "Lower Lakkari Tar Pits", ["enGB"] = "Lower Lakkari Tar Pits", ["deDE"] = "Untere Teergruben von Lakkari", ["esES"] = "Fosas de Alquitrán inferiores", ["esMX"] = "Fosas de Alquitrán inferiores", ["frFR"] = "Fosses de goudron de Lakkari inférieures", ["ruRU"] = "Нижние Смоляные ямы Лаккари", ["koKR"] = "락카리 잿구덩이 하층", ["zhTW"] = "拉卡利油沼低地",  }, continent = 1, map = 201, blob = 56380, race = 3, points = {} }, 
		["Upper Lakkari Tar Pits"] = { locales = { ["enUS"] = "Upper Lakkari Tar Pits", ["enGB"] = "Upper Lakkari Tar Pits", ["deDE"] = "Obere Teergruben von Lakkari", ["esES"] = "Fosas de Alquitrán superiores", ["esMX"] = "Fosas de Alquitrán superiores", ["frFR"] = "Fosses de goudron de Lakkari supérieures", ["ruRU"] = "Верхние Смоляные ямы Лаккари", ["koKR"] = "락카리 잿구덩이 상층", ["zhTW"] = "拉卡利油沼高原",  }, continent = 1, map = 201, blob = 56382, race = 3, points = {} }, 
		["Terror Run Fossil Field"] = { locales = { ["enUS"] = "Terror Run Fossil Field", ["enGB"] = "Terror Run Fossil Field", ["deDE"] = "Fossilienfeld der Terrorflucht", ["esES"] = "Campo de fósiles del Camino del Terror", ["esMX"] = "Campo de fósiles del Camino del Terror", ["frFR"] = "Champ de fossiles des coteaux de la Terreur", ["ruRU"] = "Путь Ужаса - ископаемая почва", ["koKR"] = "공포의 터 화석 벌판", ["zhTW"] = "恐懼小道古原野",  }, continent = 1, map = 201, blob = 56384, race = 3, points = {} }, 
		["Screaming Reaches Fossil Field"] = { locales = { ["enUS"] = "Screaming Reaches Fossil Field", ["enGB"] = "Screaming Reaches Fossil Field", ["deDE"] = "Fossilienfelder der Schreienden Weiten", ["esES"] = "Campo de fósiles de la Costa de los Gritos", ["esMX"] = "Campo de fósiles de la Costa de los Gritos", ["frFR"] = "Champ de fossile des confins Hurlants", ["ruRU"] = "Вопящие плёсы - ископаемая почва", ["koKR"] = "비명굽이 산마루 화석 벌판", ["zhTW"] = "尖嘯河岸古原野",  }, continent = 1, map = 201, blob = 56386, race = 3, points = {} }, 
		["Marshlands Fossil Bank"] = { locales = { ["enUS"] = "Marshlands Fossil Bank", ["enGB"] = "Marshlands Fossil Bank", ["deDE"] = "Fossilienbank der Marschen", ["esES"] = "Banco de fósiles de Los Pantanales", ["esMX"] = "Banco de fósiles de Los Pantanales", ["frFR"] = "Banc de fossiles de la Fondrière", ["ruRU"] = "Топи - ископаемая земля", ["koKR"] = "늪지대 화석 강둑", ["zhTW"] = "沼澤地古河岸",  }, continent = 1, map = 201, blob = 56388, race = 3, points = {} }, 
		["Southwind Village Digsite"] = { locales = { ["enUS"] = "Southwind Village Digsite", ["enGB"] = "Southwind Village Digsite", ["deDE"] = "Ausgrabungsstätte des Südwindpostens", ["esES"] = "Excavación de la Aldea del Viento del Sur", ["esMX"] = "Excavación de la Aldea del Viento del Sur", ["frFR"] = "Site de fouilles de Sudevent", ["ruRU"] = "Деревня Южного Ветра - раскопки", ["koKR"] = "마파람 마을 발굴현장", ["zhTW"] = "南風村挖掘場",  }, continent = 1, map = 261, blob = 56390, race = 4, points = {} }, 
		["Gor'gaz Outpost Digsite"] = { locales = { ["enUS"] = "Gor'gaz Outpost Digsite", ["enGB"] = "Gor'gaz Outpost Digsite", ["deDE"] = "Ausgrabungsstätte des Außenpostens von Gor'gaz", ["esES"] = "Excavación de la Avanzada Gor'gaz", ["esMX"] = "Excavación de la Avanzada Gor'gaz", ["frFR"] = "Site de fouilles de l'avant-poste de Gor'gaz", ["ruRU"] = "Форт Гор'газ - раскопки", ["koKR"] = "고르가즈 전초기지 발굴현장", ["zhTW"] = "葛卡茲哨站挖掘場",  }, continent = 3, map = 465, blob = 56392, race = 6, points = {} }, 
		["Zeth'Gor Digsite"] = { locales = { ["enUS"] = "Zeth'Gor Digsite", ["enGB"] = "Zeth'Gor Digsite", ["deDE"] = "Ausgrabungsstätte von Zeth'Gor", ["esES"] = "Excavación de Zeth'Gor", ["esMX"] = "Excavación de Zeth'Gor", ["frFR"] = "Site de fouilles de Zeth'Gor", ["ruRU"] = "Зет'Гор - раскопки", ["koKR"] = "제스고르 발굴현장", ["zhTW"] = "薩斯葛爾挖掘場",  }, continent = 3, map = 465, blob = 56394, race = 6, points = {} }, 
		["Hellfire Basin Digsite"] = { locales = { ["enUS"] = "Hellfire Basin Digsite", ["enGB"] = "Hellfire Basin Digsite", ["deDE"] = "Ausgrabungsstätte des Höllenfeuerbecken", ["esES"] = "Excavación de la Cuenca del Fuego Infernal", ["esMX"] = "Excavación de la Cuenca del Fuego Infernal", ["frFR"] = "Site de fouilles du bassin des Flammes infernales", ["ruRU"] = "Яма Адского Пламени - раскопки", ["koKR"] = "지옥불 분지 발굴현장", ["zhTW"] = "地獄火盆地挖掘場",  }, continent = 3, map = 465, blob = 56396, race = 6, points = {} }, 
		["Hellfire Citadel Digsite"] = { locales = { ["enUS"] = "Hellfire Citadel Digsite", ["enGB"] = "Hellfire Citadel Digsite", ["deDE"] = "Ausgrabungsstätte der Höllenfeuerzitadelle", ["esES"] = "Excavación de la Ciudadela del Fuego Infernal", ["esMX"] = "Excavación de la Ciudadela del Fuego Infernal", ["frFR"] = "Site de fouilles de la citadelle Flammes infernales", ["ruRU"] = "Цитадель Адского Пламени - раскопки", ["koKR"] = "지옥불 성채 발굴현장", ["zhTW"] = "地獄火堡壘挖掘場",  }, continent = 3, map = 465, blob = 56398, race = 6, points = {} }, 
		["Sha'naar Digsite"] = { locales = { ["enUS"] = "Sha'naar Digsite", ["enGB"] = "Sha'naar Digsite", ["deDE"] = "Ausgrabungsstätte von Sha'naar", ["esES"] = "Excavación de Sha'naar", ["esMX"] = "Excavación de Sha'naar", ["frFR"] = "Site de fouilles de Sha'naar", ["ruRU"] = "Ша'наар - раскопки", ["koKR"] = "샤나르 발굴현장", ["zhTW"] = "夏納挖掘場",  }, continent = 3, map = 465, blob = 56400, race = 2, points = {} }, 
		["Boha'mu Ruins Digsite"] = { locales = { ["enUS"] = "Boha'mu Ruins Digsite", ["enGB"] = "Boha'mu Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Boha'mu", ["esES"] = "Excavación de las Ruinas Boha'mu", ["esMX"] = "Excavación de las Ruinas Boha'mu", ["frFR"] = "Site de fouilles des ruines de Boha'mu", ["ruRU"] = "Руины Боха'му - раскопки", ["koKR"] = "보하무 폐허 발굴현장", ["zhTW"] = "波哈姆廢墟挖掘場",  }, continent = 3, map = 467, blob = 56402, race = 2, points = {} }, 
		["Twin Spire Ruins Digsite"] = { locales = { ["enUS"] = "Twin Spire Ruins Digsite", ["enGB"] = "Twin Spire Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen der Zwillingsspitze", ["esES"] = "Excavación de las Ruinas de las Agujas Gemelas", ["esMX"] = "Excavación de las Ruinas de las Agujas Gemelas", ["frFR"] = "Site de fouilles des ruines des Flèches jumelles", ["ruRU"] = "Руины Двух Башен - раскопки", ["koKR"] = "쌍둥이 첨탑 폐허 발굴현장", ["zhTW"] = "雙塔廢墟挖掘場",  }, continent = 3, map = 467, blob = 56404, race = 2, points = {} }, 
		["Ruins of Enkaat Digsite"] = { locales = { ["enUS"] = "Ruins of Enkaat Digsite", ["enGB"] = "Ruins of Enkaat Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Enkaat", ["esES"] = "Excavación de las Ruinas de Enkaat", ["esMX"] = "Excavación de las Ruinas de Enkaat", ["frFR"] = "Site de fouilles des ruines d'Enkaat", ["ruRU"] = "Руины Энкаата - раскопки", ["koKR"] = "엔카트 폐허 발굴현장", ["zhTW"] = "安卡特廢墟挖掘場",  }, continent = 3, map = 479, blob = 56406, race = 2, points = {} }, 
		["Arklon Ruins Digsite"] = { locales = { ["enUS"] = "Arklon Ruins Digsite", ["enGB"] = "Arklon Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Arklon", ["esES"] = "Excavación de las Ruinas Arklon", ["esMX"] = "Excavación de las Ruinas Arklon", ["frFR"] = "Site de fouilles des ruines Arklon", ["ruRU"] = "Руины Арклон - раскопки", ["koKR"] = "알클론 폐허 발굴현장", ["zhTW"] = "阿克隆廢墟挖掘場",  }, continent = 3, map = 479, blob = 56408, race = 2, points = {} }, 
		["Ruins of Farahlon Digsite"] = { locales = { ["enUS"] = "Ruins of Farahlon Digsite", ["enGB"] = "Ruins of Farahlon Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Farahlon", ["esES"] = "Excavación de las Ruinas de Farahlon", ["esMX"] = "Excavación de las Ruinas de Farahlon", ["frFR"] = "Site de fouilles des ruines de Farahlon", ["ruRU"] = "Руины Фаралона - раскопки", ["koKR"] = "파랄론 폐허 발굴현장", ["zhTW"] = "法拉隆廢墟挖掘場",  }, continent = 3, map = 479, blob = 56410, race = 2, points = {} }, 
		["Ancestral Grounds Digsite"] = { locales = { ["enUS"] = "Ancestral Grounds Digsite", ["enGB"] = "Ancestral Grounds Digsite", ["deDE"] = "Ausgrabungsstätte des Ahnengrunds", ["esES"] = "Excavación de las Tierras Ancestrales", ["esMX"] = "Excavación de las Tierras Ancestrales", ["frFR"] = "Site de fouilles des terres Ancestrales", ["ruRU"] = "Земли Предков - раскопки", ["koKR"] = "선조의 터 발굴현장", ["zhTW"] = "先祖之地挖掘場",  }, continent = 3, map = 477, blob = 56412, race = 6, points = {} }, 
		["Sunspring Post Digsite"] = { locales = { ["enUS"] = "Sunspring Post Digsite", ["enGB"] = "Sunspring Post Digsite", ["deDE"] = "Ausgrabungsstätte des Sonnenwindpostens", ["esES"] = "Excavación del Puesto Primasol", ["esMX"] = "Excavación del Puesto Primasol", ["frFR"] = "Site de fouilles du poste de Berceau-de-l'Été", ["ruRU"] = "Застава Солнечного Источника - раскопки", ["koKR"] = "태양여울 주둔지 발굴현장", ["zhTW"] = "日春崗哨挖掘場",  }, continent = 3, map = 477, blob = 56416, race = 6, points = {} }, 
		["Laughing Skull Digsite"] = { locales = { ["enUS"] = "Laughing Skull Digsite", ["enGB"] = "Laughing Skull Digsite", ["deDE"] = "Ausgrabungsstätte des Lachenden Schädels", ["esES"] = "Excavación de las Ruinas Riecráneos", ["esMX"] = "Excavación de las Ruinas Riecráneos", ["frFR"] = "Site de fouilles des ruines du Crâne ricanant", ["ruRU"] = "Веселый Череп - раскопки", ["koKR"] = "웃는 해골 발굴현장", ["zhTW"] = "獰笑骷髏挖掘場",  }, continent = 3, map = 477, blob = 56418, race = 6, points = {} }, 
		["Burning Blade Digsite"] = { locales = { ["enUS"] = "Burning Blade Digsite", ["enGB"] = "Burning Blade Digsite", ["deDE"] = "Ausgrabungsstätte der Brennenden Klinge", ["esES"] = "Excavación de las Ruinas Filo Ardiente", ["esMX"] = "Excavación de las Ruinas Filo Ardiente", ["frFR"] = "Site de fouilles de la Lame ardente", ["ruRU"] = "Пылающий Клинок - раскопки", ["koKR"] = "불타는 칼날단 발굴현장", ["zhTW"] = "燃刃挖掘場",  }, continent = 3, map = 477, blob = 56420, race = 6, points = {} }, 
		["Halaa Digsite"] = { locales = { ["enUS"] = "Halaa Digsite", ["enGB"] = "Halaa Digsite", ["deDE"] = "Ausgrabungsstätte von Haala", ["esES"] = "Excavación de Halaa", ["esMX"] = "Excavación de Halaa", ["frFR"] = "Site de fouilles d'Halaa", ["ruRU"] = "Халаа - раскопки", ["koKR"] = "할라아 발굴현장", ["zhTW"] = "哈剌挖掘場",  }, continent = 3, map = 477, blob = 56422, race = 2, points = {} }, 
		["Grangol'var Village Digsite"] = { locales = { ["enUS"] = "Grangol'var Village Digsite", ["enGB"] = "Grangol'var Village Digsite", ["deDE"] = "Ausgrabungsstätte von Grangol'var", ["esES"] = "Excavación del Poblado Grangol'var", ["esMX"] = "Excavación del Poblado Grangol'var", ["frFR"] = "Site de fouilles de Grangol'var", ["ruRU"] = "Деревня Грангол'вар - раскопки", ["koKR"] = "그란골바르 마을 발굴현장", ["zhTW"] = "葛蘭戈瓦村挖掘場",  }, continent = 3, map = 478, blob = 56424, race = 6, points = {} }, 
		["Tuurem Digsite"] = { locales = { ["enUS"] = "Tuurem Digsite", ["enGB"] = "Tuurem Digsite", ["deDE"] = "Ausgrabungsstätte von Tuurem", ["esES"] = "Excavación de Tuurem", ["esMX"] = "Excavación de Tuurem", ["frFR"] = "Site de fouilles de Tuurem", ["ruRU"] = "Туурем - раскопки", ["koKR"] = "투렘 발굴현장", ["zhTW"] = "杜瑞挖掘場",  }, continent = 3, map = 478, blob = 56426, race = 2, points = {} }, 
		["Bleeding Hollow Ruins Digsite"] = { locales = { ["enUS"] = "Bleeding Hollow Ruins Digsite", ["enGB"] = "Bleeding Hollow Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen des Blutenden Auges", ["esES"] = "Excavación de las Ruinas Foso Sangrante", ["esMX"] = "Excavación de las Ruinas Foso Sangrante", ["frFR"] = "Site de fouilles des ruines de l'Orbite sanglante", ["ruRU"] = "Руины Кровавой Глазницы - раскопки", ["koKR"] = "피눈물 폐허 발굴현장", ["zhTW"] = "血之谷廢墟挖掘場",  }, continent = 3, map = 478, blob = 56428, race = 6, points = {} }, 
		["Bonechewer Ruins Digsite"] = { locales = { ["enUS"] = "Bonechewer Ruins Digsite", ["enGB"] = "Bonechewer Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen der Knochenmalmer", ["esES"] = "Excavación de las Ruinas Mascahuesos", ["esMX"] = "Excavación de las Ruinas Mascahuesos", ["frFR"] = "Site de fouilles des ruines Mâche-les-os", ["ruRU"] = "Руины Костеглодов - раскопки", ["koKR"] = "해골이빨 폐허 발굴현장", ["zhTW"] = "噬骨者廢墟挖掘場",  }, continent = 3, map = 478, blob = 56430, race = 6, points = {} }, 
		["Bone Wastes Digsite"] = { locales = { ["enUS"] = "Bone Wastes Digsite", ["enGB"] = "Bone Wastes Digsite", ["deDE"] = "Ausgrabungsstätte der Knochenwüste", ["esES"] = "Excavación de El Vertedero de Huesos", ["esMX"] = "Excavación de El Vertedero de Huesos", ["frFR"] = "Site de fouilles du désert des Ossements", ["ruRU"] = "Костяные пустоши - раскопки", ["koKR"] = "해골 무덤 발굴현장", ["zhTW"] = "白骨荒野挖掘場",  }, continent = 3, map = 478, blob = 56432, race = 2, points = {} }, 
		["East Auchindoun Digsite"] = { locales = { ["enUS"] = "East Auchindoun Digsite", ["enGB"] = "East Auchindoun Digsite", ["deDE"] = "Östliche Ausgrabungsstätte von Auchindoun", ["esES"] = "Excavación de Auchindoun oriental", ["esMX"] = "Excavación de Auchindoun oriental", ["frFR"] = "Site de fouilles d'Auchindoun est", ["ruRU"] = "Восточный Аукиндон - раскопки", ["koKR"] = "아킨둔 동부 발굴현장", ["zhTW"] = "奧齊頓東部挖掘場",  }, continent = 3, map = 478, blob = 56434, race = 2, points = {} }, 
		["West Auchindoun Digsite"] = { locales = { ["enUS"] = "West Auchindoun Digsite", ["enGB"] = "West Auchindoun Digsite", ["deDE"] = "Westliche Ausgrabungsstätte von Auchindoun", ["esES"] = "Excavación de Auchindoun occidental", ["esMX"] = "Excavación de Auchindoun occidental", ["frFR"] = "Site de fouilles d'Auchindoun ouest", ["ruRU"] = "Западный Аукиндон - раскопки", ["koKR"] = "아킨둔 서부 발굴현장", ["zhTW"] = "奧齊頓西部挖掘場",  }, continent = 3, map = 478, blob = 56437, race = 2, points = {} }, 
		["Illidari Point Digsite"] = { locales = { ["enUS"] = "Illidari Point Digsite", ["enGB"] = "Illidari Point Digsite", ["deDE"] = "Ausgrabungsstätte der Stätte der Illidari", ["esES"] = "Excavación del Alto Illidari", ["esMX"] = "Excavación del Alto Illidari", ["frFR"] = "Site de fouilles de la halte Illidari", ["ruRU"] = "Аванпост Иллидари - раскопки", ["koKR"] = "일리다리 거점 발굴현장", ["zhTW"] = "伊利達瑞崗哨挖掘場",  }, continent = 3, map = 473, blob = 56439, race = 2, points = {} }, 
		["Coilskar Point Digsite"] = { locales = { ["enUS"] = "Coilskar Point Digsite", ["enGB"] = "Coilskar Point Digsite", ["deDE"] = "Ausgrabungsstätte der Echsennarbe", ["esES"] = "Excavación del Alto Cicatriz Espiral", ["esMX"] = "Excavación del Alto Cicatriz Espiral", ["frFR"] = "Site de fouilles de la halte de Glissentaille", ["ruRU"] = "Лагерь Змеиных Колец - раскопки", ["koKR"] = "갈퀴흉터 거점 발굴현장", ["zhTW"] = "考斯卡崗哨挖掘場",  }, continent = 3, map = 473, blob = 56441, race = 2, points = {} }, 
		["Ruins of Baa'ri Digsite"] = { locales = { ["enUS"] = "Ruins of Baa'ri Digsite", ["enGB"] = "Ruins of Baa'ri Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Baa'ri", ["esES"] = "Excavación de las Ruinas de Baa'ri", ["esMX"] = "Excavación de las Ruinas de Baa'ri", ["frFR"] = "Site de fouilles des ruines de Baa'ri", ["ruRU"] = "Руины Баа'ри - раскопки", ["koKR"] = "바아리 폐허 발굴현장", ["zhTW"] = "巴瑞廢墟挖掘場",  }, continent = 3, map = 473, blob = 56446, race = 2, points = {} }, 
		["Eclipse Point Digsite"] = { locales = { ["enUS"] = "Eclipse Point Digsite", ["enGB"] = "Eclipse Point Digsite", ["deDE"] = "Ausgrabungsstätte der Stätte der Mondfinsternis", ["esES"] = "Excavación de Punta Eclipse", ["esMX"] = "Excavación de Punta Eclipse", ["frFR"] = "Site de fouilles de la halte de l'Éclipse", ["ruRU"] = "Лагерь Затмения - раскопки", ["koKR"] = "해그늘 주둔지 발굴현장", ["zhTW"] = "日蝕崗哨挖掘場",  }, continent = 3, map = 473, blob = 56448, race = 2, points = {} }, 
		["Warden's Cage Digsite"] = { locales = { ["enUS"] = "Warden's Cage Digsite", ["enGB"] = "Warden's Cage Digsite", ["deDE"] = "Ausgrabungsstätte des Kerkers des Wächters", ["esES"] = "Excavación de la Jaula de la Guardiana", ["esMX"] = "Excavación de la Jaula de la Guardiana", ["frFR"] = "Site de fouilles de la Cage de la gardienne", ["ruRU"] = "Клеть Стражницы - раскопки", ["koKR"] = "감시자의 수용소 발굴현장", ["zhTW"] = "典獄官監牢挖掘場",  }, continent = 3, map = 473, blob = 56450, race = 6, points = {} }, 
		["Dragonmaw Fortress"] = { locales = { ["enUS"] = "Dragonmaw Fortress", ["enGB"] = "Dragonmaw Fortress", ["deDE"] = "Festung des Drachenmals", ["esES"] = "Fortaleza Faucedraco", ["esMX"] = "Fortaleza Faucedraco", ["frFR"] = "Forteresse Gueule-de-dragon", ["ruRU"] = "Крепость Драконьей Пасти", ["koKR"] = "용아귀 요새", ["zhTW"] = "龍喉堡壘",  }, continent = 3, map = 473, blob = 56455, race = 6, points = {} }, 
		["Skorn Digsite"] = { locales = { ["enUS"] = "Skorn Digsite", ["enGB"] = "Skorn Digsite", ["deDE"] = "Ausgrabungsstätte von Skorn", ["esES"] = "Excavación de Skorn", ["esMX"] = "Excavación de Skorn", ["frFR"] = "Site de fouilles de Skorn", ["ruRU"] = "Скорн - раскопки", ["koKR"] = "스코른 발굴현장", ["zhTW"] = "斯考恩挖掘場",  }, continent = 4, map = 491, blob = 56504, race = 9, points = {} }, 
		["Halgrind Digsite"] = { locales = { ["enUS"] = "Halgrind Digsite", ["enGB"] = "Halgrind Digsite", ["deDE"] = "Ausgrabungsstätte von Halgrind", ["esES"] = "Excavación de Haltorboll", ["esMX"] = "Excavación de Haltorboll", ["frFR"] = "Site de fouilles de Halegrince", ["ruRU"] = "Халгринд - раскопки", ["koKR"] = "할그린드 발굴현장", ["zhTW"] = "霍葛萊挖掘場",  }, continent = 4, map = 491, blob = 56506, race = 9, points = {} }, 
		["Wyrmskull Digsite"] = { locales = { ["enUS"] = "Wyrmskull Digsite", ["enGB"] = "Wyrmskull Digsite", ["deDE"] = "Ausgrabungsstätte von Wyrmskol", ["esES"] = "Excavación de Calavermis", ["esMX"] = "Excavación de Calavermis", ["frFR"] = "Site de fouilles de Crâne-du-ver", ["ruRU"] = "Драконий Череп - раскопки", ["koKR"] = "고룡해골 발굴현장", ["zhTW"] = "龍顱挖掘場",  }, continent = 4, map = 491, blob = 56508, race = 9, points = {} }, 
		["Shield Hill Digsite"] = { locales = { ["enUS"] = "Shield Hill Digsite", ["enGB"] = "Shield Hill Digsite", ["deDE"] = "Ausgrabungsstätte des Schildhügels", ["esES"] = "Excavación de la Colina Escudo", ["esMX"] = "Excavación de la Colina Escudo", ["frFR"] = "Site de fouilles de la colline du Bouclier", ["ruRU"] = "Заградительный холм - раскопки", ["koKR"] = "방패 언덕 발굴현장", ["zhTW"] = "盾丘挖掘場",  }, continent = 4, map = 491, blob = 56510, race = 9, points = {} }, 
		["Baleheim Digsite"] = { locales = { ["enUS"] = "Baleheim Digsite", ["enGB"] = "Baleheim Digsite", ["deDE"] = "Ausgrabungsstätte Quälheim", ["esES"] = "Excavación de Baleheim", ["esMX"] = "Excavación de Baleheim", ["frFR"] = "Site de fouilles de Torvheim", ["ruRU"] = "Гибльхейм - раскопки", ["koKR"] = "베일하임 발굴현장", ["zhTW"] = "貝爾海姆挖掘場",  }, continent = 4, map = 491, blob = 56512, race = 9, points = {} }, 
		["Nifflevar Digsite"] = { locales = { ["enUS"] = "Nifflevar Digsite", ["enGB"] = "Nifflevar Digsite", ["deDE"] = "Ausgrabungsstätte von Nifflevar", ["esES"] = "Excavación de Nifflevar", ["esMX"] = "Excavación de Nifflevar", ["frFR"] = "Site de fouilles de Nifflevar", ["ruRU"] = "Ниффлвар - раскопки", ["koKR"] = "니플바르 발굴현장", ["zhTW"] = "尼弗瓦挖掘場",  }, continent = 4, map = 491, blob = 56514, race = 9, points = {} }, 
		["Gjalerbron Digsite"] = { locales = { ["enUS"] = "Gjalerbron Digsite", ["enGB"] = "Gjalerbron Digsite", ["deDE"] = "Ausgrabungsstätte von Gjalerbron", ["esES"] = "Excavación de Gjalerbron", ["esMX"] = "Excavación de Gjalerbron", ["frFR"] = "Site de fouilles de Gjalerbron", ["ruRU"] = "Гьялерброн - раскопки", ["koKR"] = "샬레르브론 발굴현장", ["zhTW"] = "夏勒布隆挖掘場",  }, continent = 4, map = 491, blob = 56516, race = 9, points = {} }, 
		["Pit of Narjun Digsite"] = { locales = { ["enUS"] = "Pit of Narjun Digsite", ["enGB"] = "Pit of Narjun Digsite", ["deDE"] = "Ausgrabungsstätte der Grube von Narjun", ["esES"] = "Excavación de El Foso de Narjun", ["esMX"] = "Excavación de El Foso de Narjun", ["frFR"] = "Site de fouilles de la fosse de Narjun", ["ruRU"] = "Провал Наржуна - раскопки", ["koKR"] = "나르준의 구덩이 발굴현장", ["zhTW"] = "那金之淵挖掘場",  }, continent = 4, map = 488, blob = 56518, race = 5, points = {} }, 
		["Moonrest Gardens Digsite"] = { locales = { ["enUS"] = "Moonrest Gardens Digsite", ["enGB"] = "Moonrest Gardens Digsite", ["deDE"] = "Ausgrabungsstätte der Mondruhgärten", ["esES"] = "Excavación de los Jardines Reposo Lunar", ["esMX"] = "Excavación de los Jardines Reposo Lunar", ["frFR"] = "Site de fouilles des jardins de Repos-de-Lune", ["ruRU"] = "Сады Лунного Покоя - раскопки", ["koKR"] = "달쉼터 정원 발굴현장", ["zhTW"] = "月眠花園挖掘場",  }, continent = 4, map = 488, blob = 56520, race = 4, points = {} }, 
		["En'kilah Digsite"] = { locales = { ["enUS"] = "En'kilah Digsite", ["enGB"] = "En'kilah Digsite", ["deDE"] = "Ausgrabungsstätte von En'kilah", ["esES"] = "Excavación de En'kilah", ["esMX"] = "Excavación de En'kilah", ["frFR"] = "Site de fouilles d'En'kilah", ["ruRU"] = "Эн'кила - раскопки", ["koKR"] = "엔킬라 발굴현장", ["zhTW"] = "恩吉拉挖掘場",  }, continent = 4, map = 486, blob = 56522, race = 5, points = {} }, 
		["Kolramas Digsite"] = { locales = { ["enUS"] = "Kolramas Digsite", ["enGB"] = "Kolramas Digsite", ["deDE"] = "Ausgrabungsstätte von Kolramas", ["esES"] = "Excavación de Kolramas", ["esMX"] = "Excavación de Kolramas", ["frFR"] = "Site de fouilles de Kolramas", ["ruRU"] = "Колрамас - раскопки", ["koKR"] = "콜라마스 발굴현장", ["zhTW"] = "科爾拉瑪斯挖掘場",  }, continent = 4, map = 496, blob = 56524, race = 5, points = {} }, 
		["Riplash Ruins Digsite"] = { locales = { ["enUS"] = "Riplash Ruins Digsite", ["enGB"] = "Riplash Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen der Peitschennarbe", ["esES"] = "Excavación de las Ruinas Tralladón", ["esMX"] = "Excavación de las Ruinas Tralladón", ["frFR"] = "Site de fouilles des ruines des Courcinglants", ["ruRU"] = "Руины Терзающего Бича - раскопки", ["koKR"] = "채찍파도 폐허 발굴현장", ["zhTW"] = "裂鞭遺跡挖掘場",  }, continent = 4, map = 486, blob = 56526, race = 4, points = {} }, 
		["Violet Stand Digsite"] = { locales = { ["enUS"] = "Violet Stand Digsite", ["enGB"] = "Violet Stand Digsite", ["deDE"] = "Ausgrabungsstätte der Violetten Wacht", ["esES"] = "Excavación de El Confín Violeta", ["esMX"] = "Excavación de El Confín Violeta", ["frFR"] = "Site de fouilles du séjour Pourpre", ["ruRU"] = "Аметистовая застава - раскопки", ["koKR"] = "보랏빛 단 발굴현장", ["zhTW"] = "紫羅蘭看臺挖掘場",  }, continent = 4, map = 510, blob = 56528, race = 4, points = {} }, 
		["Ruins of Shandaral Digsite"] = { locales = { ["enUS"] = "Ruins of Shandaral Digsite", ["enGB"] = "Ruins of Shandaral Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Shandaral", ["esES"] = "Excavación de las Ruinas de Shandaral", ["esMX"] = "Excavación de las Ruinas de Shandaral", ["frFR"] = "Site de fouilles des ruines de Shandaral", ["ruRU"] = "Руины Шандарала - раскопки", ["koKR"] = "샨다랄 폐허 발굴현장", ["zhTW"] = "珊達拉遺跡挖掘場",  }, continent = 4, map = 510, blob = 56530, race = 4, points = {} }, 
		["Altar of Sseratus Digsite"] = { locales = { ["enUS"] = "Altar of Sseratus Digsite", ["enGB"] = "Altar of Sseratus Digsite", ["deDE"] = "Ausgrabungsstätte am Altar von Sseratus", ["esES"] = "Excavación del Altar de Sseratus", ["esMX"] = "Excavación del Altar de Sseratus", ["frFR"] = "Site de fouilles de l'autel de Sseratus", ["ruRU"] = "Алтарь Шшератуса - раскопки", ["koKR"] = "세라투스의 제단 발굴현장", ["zhTW"] = "司瑟拉圖斯祭壇挖掘場",  }, continent = 4, map = 496, blob = 56533, race = 8, points = {} }, 
		["Zim'Rhuk Digsite"] = { locales = { ["enUS"] = "Zim'Rhuk Digsite", ["enGB"] = "Zim'Rhuk Digsite", ["deDE"] = "Ausgrabungsstätte von Zim'Rhuk", ["esES"] = "Excavación de Zim'Rhuk", ["esMX"] = "Excavación de Zim'Rhuk", ["frFR"] = "Site de fouilles de Zim'Rhuk", ["ruRU"] = "Зим'Рук - раскопки", ["koKR"] = "짐루크 발굴현장", ["zhTW"] = "辛茹克挖掘場",  }, continent = 4, map = 496, blob = 56535, race = 8, points = {} }, 
		["Zol'Heb Digsite"] = { locales = { ["enUS"] = "Zol'Heb Digsite", ["enGB"] = "Zol'Heb Digsite", ["deDE"] = "Ausgrabungsstätte von Zol'Heb", ["esES"] = "Excavación de Zol'Heb", ["esMX"] = "Excavación de Zol'Heb", ["frFR"] = "Site de fouilles de Zol'Heb", ["ruRU"] = "Зол'Хеб - раскопки", ["koKR"] = "졸헤브 발굴현장", ["zhTW"] = "佐爾希伯挖掘場",  }, continent = 4, map = 496, blob = 56537, race = 8, points = {} }, 
		["Altar of Quetz'lun Digsite"] = { locales = { ["enUS"] = "Altar of Quetz'lun Digsite", ["enGB"] = "Altar of Quetz'lun Digsite", ["deDE"] = "Ausgrabungsstätte am Altar von Quetz'lun", ["esES"] = "Excavación del Altar de Quetz'lun", ["esMX"] = "Excavación del Altar de Quetz'lun", ["frFR"] = "Site de fouilles de l'autel de Quetz'lun", ["ruRU"] = "Алтарь Кетц'лун - раскопки", ["koKR"] = "쿠에츠룬의 제단 발굴현장", ["zhTW"] = "奎茲倫祭壇挖掘場",  }, continent = 4, map = 496, blob = 56539, race = 8, points = {} }, 
		["Talramas Digsite"] = { locales = { ["enUS"] = "Talramas Digsite", ["enGB"] = "Talramas Digsite", ["deDE"] = "Ausgrabungsstätte von Talramas", ["esES"] = "Excavación de Talramas", ["esMX"] = "Excavación de Talramas", ["frFR"] = "Site de fouilles de Talramas", ["ruRU"] = "Талрамас - раскопки", ["koKR"] = "탈라마스 발굴현장", ["zhTW"] = "塔爾拉瑪斯挖掘場",  }, continent = 4, map = 486, blob = 56541, race = 5, points = {} }, 
		["Voldrune Digsite"] = { locales = { ["enUS"] = "Voldrune Digsite", ["enGB"] = "Voldrune Digsite", ["deDE"] = "Ausgrabungsstätte von Voldrune", ["esES"] = "Excavación de Runavold", ["esMX"] = "Excavación de Runavold", ["frFR"] = "Site de fouilles de Voldrune", ["ruRU"] = "Волдрун - раскопки", ["koKR"] = "볼드룬 발굴현장", ["zhTW"] = "沃德盧恩挖掘場",  }, continent = 4, map = 490, blob = 56543, race = 9, points = {} }, 
		["Drakil'Jin Ruins Digsite"] = { locales = { ["enUS"] = "Drakil'Jin Ruins Digsite", ["enGB"] = "Drakil'Jin Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Drakil'jin", ["esES"] = "Excavación de las Ruinas de Drakil'Jin", ["esMX"] = "Excavación de las Ruinas de Drakil'Jin", ["frFR"] = "Site de fouilles des ruines de Drakil'jin", ["ruRU"] = "Руины Дракил'джин - раскопки", ["koKR"] = "드라킬진 폐허 발굴현장", ["zhTW"] = "德拉齊金遺跡挖掘場",  }, continent = 4, map = 490, blob = 56547, race = 8, points = {} }, 
		["Brunnhildar Village Digsite"] = { locales = { ["enUS"] = "Brunnhildar Village Digsite", ["enGB"] = "Brunnhildar Village Digsite", ["deDE"] = "Ausgrabungsstätte von Brunnhildar", ["esES"] = "Excavación del Poblado Brunnhildar", ["esMX"] = "Excavación del Poblado Brunnhildar", ["frFR"] = "Site de fouilles de Brunnhildar", ["ruRU"] = "Деревня Бруннхильдар - раскопки", ["koKR"] = "브룬힐다르 마을 발굴현장", ["zhTW"] = "布倫希爾達村挖掘場",  }, continent = 4, map = 495, blob = 56549, race = 9, points = {} }, 
		["Sifreldar Village Digsite"] = { locales = { ["enUS"] = "Sifreldar Village Digsite", ["enGB"] = "Sifreldar Village Digsite", ["deDE"] = "Ausgrabungsstätte von Sifreldar", ["esES"] = "Excavación del Poblado Sifreldar", ["esMX"] = "Excavación del Poblado Sifreldar", ["frFR"] = "Site de fouilles de Sifreldar", ["ruRU"] = "Деревня Сифрельдар - раскопки", ["koKR"] = "시프렐다르 마을 발굴현장", ["zhTW"] = "希弗爾達村挖掘場",  }, continent = 4, map = 495, blob = 56551, race = 9, points = {} }, 
		["Valkyrion Digsite"] = { locales = { ["enUS"] = "Valkyrion Digsite", ["enGB"] = "Valkyrion Digsite", ["deDE"] = "Ausgrabungsstätte von Valkyrion", ["esES"] = "Excavación de Valkyrion", ["esMX"] = "Excavación de Valkyrion", ["frFR"] = "Site de fouilles de Valkyrion", ["ruRU"] = "Валькирион - раскопки", ["koKR"] = "발키리온 발굴현장", ["zhTW"] = "華爾基倫挖掘場",  }, continent = 4, map = 495, blob = 56553, race = 9, points = {} }, 
		["Scourgeholme Digsite"] = { locales = { ["enUS"] = "Scourgeholme Digsite", ["enGB"] = "Scourgeholme Digsite", ["deDE"] = "Ausgrabungsstätte von Geißelholme", ["esES"] = "Excavación de la Ciudad de la Plaga", ["esMX"] = "Excavación de la Ciudad de la Plaga", ["frFR"] = "Site de fouilles de Fléaulme", ["ruRU"] = "Плетхольм - раскопки", ["koKR"] = "스컬지홀름 발굴현장", ["zhTW"] = "天譴岸地挖掘場",  }, continent = 4, map = 492, blob = 56555, race = 5, points = {} }, 
		["Ymirheim Digsite"] = { locales = { ["enUS"] = "Ymirheim Digsite", ["enGB"] = "Ymirheim Digsite", ["deDE"] = "Ausgrabungsstätte von Ymirheim", ["esES"] = "Excavación de Ymirheim", ["esMX"] = "Excavación de Ymirheim", ["frFR"] = "Site de fouilles d'Ymirheim", ["ruRU"] = "Имирхейм - раскопки", ["koKR"] = "이미르하임 발굴현장", ["zhTW"] = "依米海姆挖掘場",  }, continent = 4, map = 492, blob = 56560, race = 9, points = {} }, 
		["Jotunheim Digsite"] = { locales = { ["enUS"] = "Jotunheim Digsite", ["enGB"] = "Jotunheim Digsite", ["deDE"] = "Ausgrabungsstätte von Jotunheim", ["esES"] = "Excavación de Jotunheim", ["esMX"] = "Excavación de Jotunheim", ["frFR"] = "Site de fouilles de Jotunheim", ["ruRU"] = "Йотунхейм - раскопки", ["koKR"] = "요툰하임 발굴현장", ["zhTW"] = "卓頓海姆挖掘場",  }, continent = 4, map = 492, blob = 56562, race = 9, points = {} }, 
		["Njorndar Village Digsite"] = { locales = { ["enUS"] = "Njorndar Village Digsite", ["enGB"] = "Njorndar Village Digsite", ["deDE"] = "Ausgrabungsstätte von Njorndar", ["esES"] = "Excavación del Poblado Njorndar", ["esMX"] = "Excavación del Poblado Njorndar", ["frFR"] = "Site de fouilles de Njorndar", ["ruRU"] = "Деревня Ньорндар - раскопки", ["koKR"] = "요른다르 마을 발굴현장", ["zhTW"] = "尼約達村挖掘場",  }, continent = 4, map = 492, blob = 56564, race = 9, points = {} }, 
		["Ruins of Lar'donir Digsite"] = { locales = { ["enUS"] = "Ruins of Lar'donir Digsite", ["enGB"] = "Ruins of Lar'donir Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Lar'donir", ["esES"] = "Excavación de las Ruinas de Lar'donir", ["esMX"] = "Excavación de las Ruinas de Lar'donir", ["frFR"] = "Site de fouilles des ruines de Lar'donir", ["ruRU"] = "Руины Лар'донира - раскопки", ["koKR"] = "라르도니르 폐허 발굴현장", ["zhTW"] = "拉多尼爾廢墟挖掘場",  }, continent = 1, map = 606, blob = 56566, race = 4, points = {} }, 
		["Shrine of Goldrinn Digsite"] = { locales = { ["enUS"] = "Shrine of Goldrinn Digsite", ["enGB"] = "Shrine of Goldrinn Digsite", ["deDE"] = "Ausgrabungsstätte des Schrein von Goldrinn", ["esES"] = "Excavación del Santuario de Goldrinn", ["esMX"] = "Excavación del Santuario de Goldrinn", ["frFR"] = "Site de fouilles du sanctuaire de Goldrinn", ["ruRU"] = "Святилище Голдринна - раскопки", ["koKR"] = "골드린의 제단 발굴현장", ["zhTW"] = "戈德林聖壇挖掘場",  }, continent = 1, map = 606, blob = 56568, race = 4, points = {} }, 
		["Grove of Aessina Digsite"] = { locales = { ["enUS"] = "Grove of Aessina Digsite", ["enGB"] = "Grove of Aessina Digsite", ["deDE"] = "Ausgrabungsstätte des Hains von Aessina", ["esES"] = "Excavación de la Arboleda de Aessina", ["esMX"] = "Excavación de la Arboleda de Aessina", ["frFR"] = "Site de fouilles du bosquet d'Aessina", ["ruRU"] = "Роща Эссины - раскопки", ["koKR"] = "아에시나의 숲 발굴현장", ["zhTW"] = "艾森娜之林挖掘場",  }, continent = 1, map = 606, blob = 56570, race = 4, points = {} }, 
		["Sanctuary of Malorne Digsite"] = { locales = { ["enUS"] = "Sanctuary of Malorne Digsite", ["enGB"] = "Sanctuary of Malorne Digsite", ["deDE"] = "Ausgrabungsstätte des Heiligtums von Malorne", ["esES"] = "Excavación del Santuario de Malorne", ["esMX"] = "Excavación del Santuario de Malorne", ["frFR"] = "Site de fouilles du sanctuaire de Malorne", ["ruRU"] = "Святилище Малорна - раскопки", ["koKR"] = "말로른의 성역 발굴현장", ["zhTW"] = "瑪洛尼聖地挖掘場",  }, continent = 1, map = 606, blob = 56572, race = 4, points = {} }, 
		["Scorched Plain Digsite"] = { locales = { ["enUS"] = "Scorched Plain Digsite", ["enGB"] = "Scorched Plain Digsite", ["deDE"] = "Ausgrabungsstätte der Verbrannten Ebene", ["esES"] = "Excavación de La Llanura Agostada", ["esMX"] = "Excavación de La Llanura Agostada", ["frFR"] = "Site de fouilles de la plaine Incendiée", ["ruRU"] = "Выжженная равнина - раскопки", ["koKR"] = "불타버린 평원 발굴현장", ["zhTW"] = "烈焰平原挖掘場",  }, continent = 1, map = 606, blob = 56574, race = 4, points = {} }, 
		["Quel'Dormir Gardens Digsite"] = { locales = { ["enUS"] = "Quel'Dormir Gardens Digsite", ["enGB"] = "Quel'Dormir Gardens Digsite", ["deDE"] = "Ausgrabungsstätte der Gärten von Quel'Dormir", ["esES"] = "Excavación de los Jardines de Quel'Dormir", ["esMX"] = "Excavación de los Jardines de Quel'Dormir", ["frFR"] = "Site de fouilles des jardins de Quel'Dormir", ["ruRU"] = "Сады Кель'Дормир - раскопки", ["koKR"] = "쿠엘도르미르 정원 발굴현장", ["zhTW"] = "奎多米爾花園挖掘場",  }, continent = 2, map = 615, blob = 56576, race = 4, points = {} }, 
		["Nar'shola (Middle Tier) Digsite"] = { locales = { ["enUS"] = "Nar'shola (Middle Tier) Digsite", ["enGB"] = "Nar'shola (Middle Tier) Digsite", ["deDE"] = "Ausgrabungsstätte von Nar'shola", ["esES"] = "Excavación de Nar'shola (nivel medio)", ["esMX"] = "Excavación de Nar'shola (nivel medio)", ["frFR"] = "Site de fouilles de Nar'shola (étage du milieu)", ["ruRU"] = "Нар'шола (центральный ярус) - раскопки", ["koKR"] = "나르숄라 중앙 지구 발굴현장", ["zhTW"] = "納爾朔拉殿堂(中層)挖掘場",  }, continent = 2, map = 615, blob = 56578, race = 4, points = {} }, 
		["Biel'aran Ridge Digsite"] = { locales = { ["enUS"] = "Biel'aran Ridge Digsite", ["enGB"] = "Biel'aran Ridge Digsite", ["deDE"] = "Ausgrabungsstätte des Biel'arangrats", ["esES"] = "Excavación de la Cresta Biel'aran", ["esMX"] = "Excavación de la Cresta Biel'aran", ["frFR"] = "Site de fouilles de la crête de Biel'aran", ["ruRU"] = "Гряда Бейл'аран - раскопки", ["koKR"] = "비엘아란 마루 발굴현장", ["zhTW"] = "畢耶拉蘭山脊挖掘場",  }, continent = 2, map = 615, blob = 56580, race = 4, points = {} }, 
		["Dunwald Ruins Digsite"] = { locales = { ["enUS"] = "Dunwald Ruins Digsite", ["enGB"] = "Dunwald Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Dunwald", ["esES"] = "Excavación de las Ruinas Montocre", ["esMX"] = "Excavación de las Ruinas Montocre", ["frFR"] = "Site de fouilles des ruines de Dunwald", ["ruRU"] = "Руины Дунвальда - раскопки", ["koKR"] = "둔왈트 폐허 발굴현장", ["zhTW"] = "登瓦德廢墟挖掘場",  }, continent = 2, map = 700, blob = 56583, race = 1, points = {} }, 
		["Thundermar Ruins Digsite"] = { locales = { ["enUS"] = "Thundermar Ruins Digsite", ["enGB"] = "Thundermar Ruins Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Donnermar", ["esES"] = "Excavación de las Ruinas de Bramal", ["esMX"] = "Excavación de las Ruinas de Bramal", ["frFR"] = "Site de fouilles des ruines de Tonnemar", ["ruRU"] = "Руины Громтара - раскопки", ["koKR"] = "썬더마 폐허 발굴현장", ["zhTW"] = "桑德瑪遺跡挖掘場",  }, continent = 2, map = 700, blob = 56585, race = 1, points = {} }, 
		["Humboldt Conflagration Digsite"] = { locales = { ["enUS"] = "Humboldt Conflagration Digsite", ["enGB"] = "Humboldt Conflagration Digsite", ["deDE"] = "Ausgrabungsstätte der Humboldtfeuersbrunst", ["esES"] = "Excavación de la Conflagración de Humboldt", ["esMX"] = "Excavación de la Conflagración de Humboldt", ["frFR"] = "Site de fouilles de la déflagration de Humboldt", ["ruRU"] = "Пожарище Гумбольдта - раскопки", ["koKR"] = "훔볼트 불자리 발굴현장", ["zhTW"] = "杭伯特焚焰地挖掘場",  }, continent = 2, map = 700, blob = 56587, race = 1, points = {} }, 
		["Grim Batol Digsite"] = { locales = { ["enUS"] = "Grim Batol Digsite", ["enGB"] = "Grim Batol Digsite", ["deDE"] = "Ausgrabungsstätte von Grim Batol", ["esES"] = "Excavación de Grim Batol", ["esMX"] = "Excavación de Grim Batol", ["frFR"] = "Site de fouilles de Grim Batol", ["ruRU"] = "Грим Батол - раскопки", ["koKR"] = "그림 바톨 발굴현장", ["zhTW"] = "格瑞姆巴托挖掘場",  }, continent = 2, map = 700, blob = 56589, race = 1, points = {} }, 
		["Khartut's Tomb Digsite"] = { locales = { ["enUS"] = "Khartut's Tomb Digsite", ["enGB"] = "Khartut's Tomb Digsite", ["deDE"] = "Ausgrabungsstätte des Grabs des Khartut", ["esES"] = "Excavación de la Tumba de Khartut", ["esMX"] = "Excavación de la Tumba de Khartut", ["frFR"] = "Site de fouilles de la tombe de Khartut", ["ruRU"] = "Гробница Хартута - раскопки", ["koKR"] = "카르투트의 무덤 발굴현장", ["zhTW"] = "卡爾吐特之墓挖掘場",  }, continent = 1, map = 720, blob = 56591, race = 7, points = {} }, 
		["Tombs of the Precursors Digsite"] = { locales = { ["enUS"] = "Tombs of the Precursors Digsite", ["enGB"] = "Tombs of the Precursors Digsite", ["deDE"] = "Ausgrabungsstätte der Gräber der Wegbereiter", ["esES"] = "Excavación de las Tumbas de los Precursores", ["esMX"] = "Excavación de las Tumbas de los Precursores", ["frFR"] = "Site de fouilles des tombes des Précurseurs", ["ruRU"] = "Гробницы Предтеч - раскопки", ["koKR"] = "선도자의 무덤 발굴현장", ["zhTW"] = "先驅者之墓挖掘場",  }, continent = 1, map = 720, blob = 56593, race = 7, points = {} }, 
		["Steps of Fate Digsite"] = { locales = { ["enUS"] = "Steps of Fate Digsite", ["enGB"] = "Steps of Fate Digsite", ["deDE"] = "Ausgrabungsstätte der Schicksalsstiege", ["esES"] = "Excavación de Los Pasos del Sino", ["esMX"] = "Excavación de Los Pasos del Sino", ["frFR"] = "Site de fouilles des marches du Destin", ["ruRU"] = "Шаги Судьбы - раскопки", ["koKR"] = "운명의 계단 발굴현장", ["zhTW"] = "天命之階挖掘場",  }, continent = 1, map = 720, blob = 56595, race = 7, points = {} }, 
		["Neferset Digsite"] = { locales = { ["enUS"] = "Neferset Digsite", ["enGB"] = "Neferset Digsite", ["deDE"] = "Ausgrabungsstätte von Neferset", ["esES"] = "Excavación de Neferset", ["esMX"] = "Excavación de Neferset", ["frFR"] = "Site de fouilles de Neferset", ["ruRU"] = "Неферсет - раскопки", ["koKR"] = "네페르세트 발굴현장", ["zhTW"] = "奈斐賽特挖掘場",  }, continent = 1, map = 720, blob = 56597, race = 7, points = {} }, 
		["Orsis Digsite"] = { locales = { ["enUS"] = "Orsis Digsite", ["enGB"] = "Orsis Digsite", ["deDE"] = "Ausgrabungsstätte von Orsis", ["esES"] = "Excavación de Orsis", ["esMX"] = "Excavación de Orsis", ["frFR"] = "Site de fouilles d'Orsis", ["ruRU"] = "Орсис - раскопки", ["koKR"] = "오르시스 발굴현장", ["zhTW"] = "奧爾希斯挖掘場",  }, continent = 1, map = 720, blob = 56599, race = 7, points = {} }, 
		["Ruins of Ammon Digsite"] = { locales = { ["enUS"] = "Ruins of Ammon Digsite", ["enGB"] = "Ruins of Ammon Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Ammon", ["esES"] = "Excavación de las Ruinas de Ammon", ["esMX"] = "Excavación de las Ruinas de Ammon", ["frFR"] = "Site de fouilles des ruines d'Ammon", ["ruRU"] = "Руины Аммона - раскопки", ["koKR"] = "암몬 폐허 발굴현장", ["zhTW"] = "亞蒙廢墟挖掘場",  }, continent = 1, map = 720, blob = 56601, race = 7, points = {} }, 
		["Ruins of Khintaset Digsite"] = { locales = { ["enUS"] = "Ruins of Khintaset Digsite", ["enGB"] = "Ruins of Khintaset Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Khintaset", ["esES"] = "Excavación de las Ruinas de Khintaset", ["esMX"] = "Excavación de las Ruinas de Khintaset", ["frFR"] = "Site de fouilles des ruines de Khintaset", ["ruRU"] = "Руины Кинтасета - раскопки", ["koKR"] = "킨타세트 폐허 발굴현장", ["zhTW"] = "克因塔賽廢墟挖掘場",  }, continent = 1, map = 720, blob = 56603, race = 7, points = {} }, 
		["Temple of Uldum Digsite"] = { locales = { ["enUS"] = "Temple of Uldum Digsite", ["enGB"] = "Temple of Uldum Digsite", ["deDE"] = "Ausgrabungsstätte des Tempels von Uldum", ["esES"] = "Excavación del Templo de Uldum", ["esMX"] = "Excavación del Templo de Uldum", ["frFR"] = "Site de fouilles du temple d'Uldum", ["ruRU"] = "Храм Ульдума - раскопки", ["koKR"] = "울둠 사원 발굴현장", ["zhTW"] = "奧丹姆神廟挖掘場",  }, continent = 1, map = 720, blob = 56605, race = 7, points = {} }, 
		["Ruins of Ahmtul Digsite"] = { locales = { ["enUS"] = "Ruins of Ahmtul Digsite", ["enGB"] = "Ruins of Ahmtul Digsite", ["deDE"] = "Ausgrabungsstätte der Ruinen von Ahmtul", ["esES"] = "Excavación de las Ruinas de Ahmtul", ["esMX"] = "Excavación de las Ruinas de Ahmtul", ["frFR"] = "Site de fouilles des ruines d'Ahmtul", ["ruRU"] = "Руины Атмула - раскопки", ["koKR"] = "암툴 폐허", ["zhTW"] = "阿姆圖爾廢墟挖掘場",  }, continent = 1, map = 720, blob = 56607, race = 7, points = {} }, 
	}

	-- Generate a translation table for native dig site name look ups
	local myLocale = GetLocale()
	if myLocale == "enGB" then myLocale = "enUS" end
	for name,site in pairs(siteData) do
		if site.locales[myLocale] then
			siteTranslation[site.locales[myLocale]] = name
		end
	end
	
	local orig = GetCurrentMapAreaID()
	for cid, zlist in ipairs{GetMapContinents()} do
		SetMapZoom(cid)
		local mapid = GetCurrentMapAreaID()
		mapcz[mapid] = {cid, 0}
		for zid, mapid in ipairs{GetMapZones(cid)} do
			SetMapZoom(cid, zid)
			local mapid = GetCurrentMapAreaID()
			mapcz[mapid] = {cid,zid}
		end
	end
	SetMapByID(orig)
end

function lib:GetRaceIDsForContinent(continent)
	local races = {}
	for _,site in pairs(siteData) do
		if site.continent == continent then
			tinsert(races, site.race)
		end
	end
	return races
end

function lib:GetArtifactInfoByArtifactName(name, raceID)
	local raceCount = raceID or GetNumArchaeologyRaces()
	local raceStart = raceID or 1
	for raceIndex = raceStart,raceCount do
		local artifactCount = GetNumArtifactsByRace(raceIndex)
		for artifactIndex = 1, artifactCount do
			local artifactName, description, rarity, icon, spellDescription, numSockets, bgTexture, firstCompletionTime, completionCount = GetArtifactInfoByRace(raceIndex, artifactIndex);
			if name == artifactName then
				local raceName, currency, texture, itemID = GetArchaeologyRaceInfo(raceIndex)
				return { id = raceIndex, name = raceName, currency = currency, texture = texture, keystoneID = itemID }, 
					{ name = artifactName, description = description, rarity = rarity, icon = icon, spellDescription = spellDescription, sockets = numSockets, backgroundTexture = bgTexture, firstCompletionTime = firstCompletionTime, completionCount = completionCount }
			end
		end
	end
	return nil, nil
end

function lib:GetArtifactCompletionCount(name, race)
	local _, artifact = self:GetArtifactInfoByArtifactName(name, race)
	if artifact then return artifact.completionCount end
	return nil
end

local artifacts = {}
function lib:GetArtifactInformation(race, force)
	if not lib:PlayerHasArchaeology() then return nil end
	if not lib:IsValidRace(race) then return nil end
	local artifact
	if not artifacts[race] or force then
--		print("GetArtifactInformation called for " .. race)
		-- force an update
		local raceName, currency, texture, itemID = GetArchaeologyRaceInfo(race)
		local numProjects = GetNumArtifactsByRace(race)
		if not numProjects or numProjects == 0 then	return nil end

		local name, description, rarity, icon, spellDescription, numSockets, bgTexture = GetActiveArtifactByRace(race)
		SetSelectedArtifact(race)
		local base, adjust, totalCost = GetArtifactProgress()
		numSockets = numSockets or 0
		local keystones = 0
		local keystoneName
		if itemID and itemID > 0 then
			local itemName, itemLink, itemRarity, itemLevel, itemMinLevel, itemType, itemSubType, itemStackCount, itemEquipLoc, itemTexture, itemSellPrice = GetItemInfo(itemID)
			keystoneName = itemName
			keystones = GetItemCount(itemID)
		end
		local completionCount = self:GetArtifactCompletionCount(name, race) or 0
		artifact = {
			race = { id = race, name = raceName, currency = currency, texture = texture },
			keystone = { id = itemID, name = keystoneName, count = keystones, fragmentAdjust = adjust},
			name = name,
			description = description,
			rarity = rarity,
			icon = icon,
			spellDescription = spellDescription,
			sockets = numSockets,
			backgroundTexture = bgTexture,
			fragments = base,
			fragmentsRequired = totalCost,
			completionCount = completionCount,
		}
		artifacts[race] = artifact
	else
		-- update keystone only
		artifacts[race].keystoneCount = GetItemCount(artifacts[race].keystoneID)
		artifact = artifacts[race]
	end
	return artifact
end

function lib:GetActiveArtifacts()
	if GetNumArchaeologyRaces() == 0  then return nil end
	local ret = {}
	for race=1,GetNumArchaeologyRaces() do
		ret[race] = lib:GetArtifactInformation(race)
	end
	return ret
end

function lib:IsValidRace(race)
	local raceCount = GetNumArchaeologyRaces()
	if raceCount == 0 or race > raceCount or race < 1 then 
		return false
	else
		return true
	end
end

function lib:PlayerHasArchaeology()
	local _, _, arch = GetProfessions()
	if arch then return true else return false end
end

function lib:GetArchaeologyRank()
	local _, _, arch = GetProfessions()
	if arch then
		local _, _, rank, maxRank = GetProfessionInfo(arch)
		return rank, maxRank
	else
		return nil, nil
	end
end

function lib:GetSiteData(name)
	if siteTranslation[name] then
		return siteData[siteTranslation[name]]
	else
		return nil
	end
end

function lib:GetLastSurveyPosition()
	return lastSurveyPosition
end

function lib:GetLastSite()
	return lastSite
end

function lib:GetNearestSite()
	local sites = lib:GetSitesForContinent(GetCurrentMapContinent())
	local closest
	local distance
	if sites then
		for _, site in ipairs(sites) do
			local distToSite = lib:DistanceToSite(site.name)
			if not distance then 
				distance = distToSite 
				closest = site
			elseif distance > distToSite then
				distance = distToSite 
				closest = site
			end
		end
		return closest
	else
		return nil
	end
end

function priv:SpellCastSuccess(unit, spell, _, _, spellid)
	if unit == "player" and spellid == 80451 then
		local m,f,c,z,x,y = lib:GetPlayerPosition()
		if m and f and x and y then
			lastSurveyPosition = { map = m, floor = f, continent = c, zone = z, x = x, y = y }
			lastSite = lib:GetNearestSite()
		else
			lastSurveyPosition = nil
			lastSite = nil
		end
		lib.callbacks:Fire("PlayerSurveyed", lastSurveyPosition, lastSite)
	end
end 

function priv:CheckLoot(msg)
	local fragment_type, amount = priv:MatchFormat(msg, CURRENCY_GAINED_MULTIPLE)
	if fragment_type and string.find(string.lower(msg), string.lower(PROFESSIONS_ARCHAEOLOGY)) then
		if currencies[fragment_type] == nil or races[currencies[fragment_type]] == nil then priv:LoadTables(true) end	-- force reload of tables for new archaeologists discovering a race for the first time
		local raceId = races[currencies[fragment_type]]
		lib.callbacks:Fire("ReceivedFragments", raceId, currencies[fragment_type], amount)
	else
		local _, itemLink, amount = priv:ParseLootMessage(msg);
		if not itemLink then return end
		local itemId = priv:GetIDFromLink(itemLink)
		if keystones[itemId] then
			local raceId = keystones[itemId]
			lib.callbacks:Fire("ReceivedKeystone", raceId, itemId, amount)
		end
	end
end

function priv:GetIDFromLink(link)
	if link then
		local found, _, string = string.find(link, "^|c%x+|H(.+)|h%[.+%]")
	
		if found then
			local _, id = strsplit(":", string)
		
			return tonumber(id);
		else
			return nil
		end
	end
end

function priv:ParseLootMessage(msg)
  local player = UnitName("player")
  local item, quantity = priv:MatchFormat(msg, LOOT_ITEM_SELF_MULTIPLE)
  if item and quantity then
    return player, item, tonumber(quantity)
  end
  quantity = 1
  item = priv:MatchFormat(msg, LOOT_ITEM_SELF)
  if item then
    return player, item, tonumber(quantity)
  end

  player, item, quantity = priv:MatchFormat(msg, LOOT_ITEM_MULTIPLE)
  if player and item and quantity then
    return player, item, tonumber(quantity)
  end

  quantity = 1
  player, item = priv:MatchFormat(msg, LOOT_ITEM)
  return player, item, tonumber(quantity)
end

function priv:MatchFormat(msg, fmt)
	local newpattern = string.gsub(string.gsub(fmt, "(%%s)", "(.+)"), "(%%d)", "(.+)")
	return string.match(msg, newpattern)
end

function lib:DigSiteUpdated()
	if not races then return end
	for cid, zlist in ipairs{GetMapContinents()} do
		currSites[cid] = lib:GetSitesForContinent(cid, true)
	end
	priv:MapChanged(true)
	lib.callbacks:Fire("DigSitesUpdated")
end

function lib.callbacks:OnUsed(target, eventname)
	--lib:
	--print("Someone just registered for " .. eventname .. "!")
end
function lib.callbacks:OnUnused(target, eventname)
	
	--print("Someone just unregistered for " .. eventname .. "!")
end


function lib:GetZoneBlobs()
	local mapSites = {}
	local count = 0

	local orig = GetCurrentMapAreaID()
	SetMapToCurrentZone()
	local numEntries = ArchaeologyMapUpdateAll()
	for i = 1, numEntries do
		local blobID = ArcheologyGetVisibleBlobID(i)
		for name, site in pairs(siteData) do
			if site.blob == blobID then
				mapSites[name] = site
				count = count + 1
			end
		end
	end
	SetMapByID(orig)
	if count == 0 then return nil end
	return mapSites	
end

function priv:MapChanged(force)
	if lib:ZoneHasBlobData(force) then
		local count = 0
		local actual = 0
		table.foreach(lastBlobData, function(k,v) 
			count = count + 1 	
		end)
		lib.callbacks:Fire("MapChanged", count)
	else
		lib.callbacks:Fire("MapChanged")
	end
end

function lib:ZoneHasBlobData(force)
	local map,floor,c,z,x,y = lib:GetPlayerPosition()
	if not x and not y then return false end

	if map ~= lastMap or floor ~= lastFloor or force then
		lastMap = map
		lastFloor = floor
		lastBlobData = lib:GetZoneBlobs()
	end
	if lastBlobData then 
		return true 
	else 
		return false 
	end
end

function lib:GetLocaleSiteNameFromBlobID(blobID)
	local locale = GetLocale()
	for name,site in pairs(siteData) do
		if site.blob == blobID then
			if site.locales[myLocale] then
				return site.locales[myLocale]
			end
		end
	end
	return nil
end

function lib:GetSiteDataForBlobID(blobID)
	for _, site in pairs(siteData) do
		if site.blob == blobID then
			return site
		end
	end
	return nil
end

function lib:GetSiteDataForMap(mapID)
	local mapSites = {}
	local count = 0
	for name, site in pairs(siteData) do
		if site.map == mapID then
			local localeName = GetLocaleSiteNameFromBlobID(site.blob)
			mapSites[localeName] = site
			count = count + 1
		end
	end
	if count == 0 then return nil end
	return mapSites	
end


--[[
	Get the continent sites
]]
function lib:GetSitesForContinent(continent, force)
	if not force then
		return currSites[continent]
	else
		local sites = {}
		SetMapZoom(continent)
		local totalPOIs = GetNumMapLandmarks()
		for index = 1,totalPOIs do
			local name, description, textureIndex, px, py = GetMapLandmarkInfo(index)
			if textureIndex == lib.SITE_TEXTURE_INDEX then
				local zoneName, fileName, texPctX, texPctY, texX, texY, scrollX, scrollY = UpdateMapHighlight(px, py)
		
				local site = lib:GetSiteData(name)
				if site then
					local zoneID = priv:GetZoneID(zoneName)
					local mc, fc = priv:GetMapFloor(continent, 0)
					local mz, fz = priv:GetMapFloor(continent, zoneID)
					local x, y = astrolabe:TranslateWorldMapPosition(mc, fc, px, py, mz, fz)
					
					local raceName, currency, texture, stoneID = GetArchaeologyRaceInfo(site.race);
					
					local digsite = {
						continent = site.continent,
						zone = { id = zoneID, name = zoneName },
						location = { map = mz, floor = fz, x = x, y = y },
						name = name,
						race = { id = site.race, name = raceName, currency = currency, texture = texture, stoneID = stoneID },
						blob = { id = site.blob }, --, points = self:TranslatePoints(site.points) },
					}

					tinsert(sites, digsite)
				end
			end
		end
		SetMapToCurrentZone()
		currSites[continent] = sites
		return sites
	end
end


function lib:GetPlayerPosition()
	local m, f, x, y = astrolabe:GetCurrentPlayerPosition()
	
	local cz = mapcz[m];
	if cz then
		local c, z = unpack(cz)
--		print(m,f,c,z,x,y)
		return m, f, c, z, x, y
	end
end

function lib:DistanceToSite(name)
	local m, f, c, z, x, y = lib:GetPlayerPosition()
	
	if m and f and x and y then
		for _, continent in ipairs(currSites) do
			for _, site in ipairs(continent) do
				if site.name == name then
					local distance, _, _ = astrolabe:ComputeDistance(m, f, x, y, site.location.map, site.location.floor, site.location.x, site.location.y)
					return distance
				end
			end
		end
	end
	return nil
end

local artifactChecked
function lib:IsArtifactSolvable(race, useStones)
	local raceName, currency, texture, stoneID = GetArchaeologyRaceInfo(race)
	local projectCount = GetNumArtifactsByRace(race)
	if projectCount and projectCount > 0 then
		local name, description, rarity, icon, spellDescription, numSockets, bgTexture = GetActiveArtifactByRace(race)
		artifactChecked = { name = name, rarity = rarity, raceID = race, raceName = raceName }
		SetSelectedArtifact(race)
		local base, adjust, totalCost = GetArtifactProgress()
		
		if numSockets and numSockets > 0 then
			for socketNum = 1, numSockets do
				if useStones and not ItemAddedToArtifact(stoneID) then
					SocketItemToArtifact()
				elseif not useStones and ItemAddedToArtifact(stoneID) then
					RemoveItemFromArtifact()
				end
			end
		end
		
		local base, adjust, total = GetArtifactProgress()
		return CanSolveArtifact()
	else
		artifactChecked = nil
		return false
	end
end

local artifactSolved
function lib:SolveArtifact(race, useStones)
	if lib:IsArtifactSolvable(race, useStones) then
		if artifactChecked then
			artifactSolved = artifactChecked
			artifactChecked = nil
		end
		SolveArtifact()
	end
end

local KEYSTONE_FRAGMENT_VALUE = 12
function lib:ComputeSocketAdjustment(numSockets, keystones)
	local adjust = 0
	if numSockets > 0 then
		if keystones >= numSockets then
			adjust = numSockets * KEYSTONE_FRAGMENT_VALUE
		else
			adjust = keystones * KEYSTONE_FRAGMENT_VALUE
		end
	end
	return adjust
end



function priv:GetMapFloor(c, z)
	local mapId = astrolabe:GetMapID(c, z)
	local floors = astrolabe:GetNumFloors(mapId)
	local fl = floors == 0 and 0 or 1
	return mapId, fl
end

function priv:GetZoneName(id)
	local zones = { GetMapZones(GetCurrentMapContinent()) }
	for zoneid, zonename in pairs(zones) do
		if zoneid == id then
			return zonename
		end
	end
	return nil
end

function priv:GetZoneID(name)
	local zones = { GetMapZones(GetCurrentMapContinent()) }
	for zoneid, zonename in pairs(zones) do
		if zonename == name then
			return zoneid
		end
	end
	return nil
end

do
	local tooltipLeftText1 = _G["GameTooltipTextLeft1"]
	local prevSpell, curSpell, foundTarget
	local archSpell = (GetSpellInfo(73979)) -- Searching for Artifacts spell
	local frame = CreateFrame("Frame")
	frame:RegisterEvent("UNIT_SPELLCAST_SENT")
	frame:RegisterEvent("UNIT_SPELLCAST_STOP")
	frame:RegisterEvent("UNIT_SPELLCAST_FAILED")
	frame:RegisterEvent("UNIT_SPELLCAST_INTERRUPTED")
	frame:RegisterEvent("CURSOR_UPDATE")
	frame:RegisterEvent("LOOT_CLOSED")


	local function GetWorldTarget()
		if foundTarget then return end
		if (MinimapCluster:IsMouseOver()) then return end
		local what = tooltipLeftText1:GetText()
	end

	local function GetIDForNode(name)
		return surveyNodeIDs[name]
	end


	local function addItem(what, nid)
		local x, y = GetPlayerMapPosition("player")
		if x == 0 and y == 0 then return end
		if GetMapInfo() == "ScarletEnclave" then return end
		local zone = GetCurrentMapAreaID()
		local level = GetCurrentMapDungeonLevel()
		if not what then return end
		local range = 10
		if not nid then return end
		local skip = false
		print(what, " was found at ", floor(x * 10000) / 100, ", ", floor(y * 10000) / 100)
	end

	local function SpellStarted(unit,spellcast,rank,target)
		if unit ~= "player" then return end
		foundTarget = false
		if spellcast == archSpell then
--			print("Unit: ", unit, " Target: ", target, " Spellcast: ", spellcast, " Rank: ", rank, " Target: ", target)
			curSpell = spellcast
			prevSpell = spellcast
			local nodeID = GetIDForNode(target)
			if nodeID then -- seem 2.4 has the node name now as the target
				addItem(target, nodeID)
	--			self:addItem(prevSpell,target)
				foundTarget = true
			else
				GetWorldTarget()
			end
		else
			prevSpell, curSpell = nil, nil
		end
	end

	local function SpellFailed(unit)
		if unit ~= "player" then return end
		prevSpell, curSpell = nil, nil
	end


	local function SpellStopped(unit)
		if unit ~= "player" then return end
		if archSpell == prevSpell then
			GetWorldTarget()
		end
		
		prevSpell, curSpell = curSpell, curSpell
	end


	local function CursorChange()
		if foundTarget then return end
		if (MinimapCluster:IsMouseOver()) then return end
		if archSpell == prevSpell then
			GetWorldTarget()
		end
	end

	local function GatherCompleted()
		prevSpell, curSpell = nil, nil
		foundTarget = false
	end

	frame:SetScript("OnEvent", function(frame, event, ...)
		if event == "UNIT_SPELLCAST_SENT" then
			SpellStarted(...)
		elseif event == "UNIT_SPELLCAST_STOP" then
			SpellStopped(...)
		elseif event == "UNIT_SPELLCAST_FAILED" or event == "UNIT_SPELLCAST_INTERRUPTED" then
			SpellFailed(...)
		elseif event == "CURSOR_UPDATE" then
			CursorChange(...)
		elseif event == "LOOT_CLOSED" then
			GatherCompleted(...)
		end
	end)
end